var group__PkgKernel23ConceptsFunctionObjects =
[
    [ "Kernel::Angle_2", "classKernel_1_1Angle__2.html", [
      [ "operator()", "classKernel_1_1Angle__2.html#a45f9ca06ad3b86d72d27dd909008e8de", null ],
      [ "operator()", "classKernel_1_1Angle__2.html#a384862f48f7dd0f64ff91fa70a14d583", null ],
      [ "operator()", "classKernel_1_1Angle__2.html#a3fa919e35d0db99ef348021a851b0c0f", null ]
    ] ],
    [ "Kernel::Angle_3", "classKernel_1_1Angle__3.html", [
      [ "operator()", "classKernel_1_1Angle__3.html#a1937a1a27d17e0c47a8e5b36a8f0e856", null ],
      [ "operator()", "classKernel_1_1Angle__3.html#af32f055dda7e3af1de26a70b7d5d9fb2", null ],
      [ "operator()", "classKernel_1_1Angle__3.html#a362be33c73a3ebf3a7691343019f2ef2", null ],
      [ "operator()", "classKernel_1_1Angle__3.html#a8f9c12ba6e2210f50fb6a192df9e3af4", null ]
    ] ],
    [ "Kernel::AreOrderedAlongLine_2", "classKernel_1_1AreOrderedAlongLine__2.html", [
      [ "operator()", "classKernel_1_1AreOrderedAlongLine__2.html#ab5f06b9d09599dc79576d069ecd4cf2c", null ]
    ] ],
    [ "Kernel::AreOrderedAlongLine_3", "classKernel_1_1AreOrderedAlongLine__3.html", [
      [ "operator()", "classKernel_1_1AreOrderedAlongLine__3.html#a7856567ee2674df1b9020b03aa262420", null ]
    ] ],
    [ "Kernel::AreParallel_2", "classKernel_1_1AreParallel__2.html", [
      [ "operator()", "classKernel_1_1AreParallel__2.html#ab49d7864ba9f4ee239564af8aeb4f73f", null ],
      [ "operator()", "classKernel_1_1AreParallel__2.html#a92e6bcbfb2274261ecdf98b0410f0609", null ],
      [ "operator()", "classKernel_1_1AreParallel__2.html#a06aad2401009520d89a7c16100917a3c", null ]
    ] ],
    [ "Kernel::AreParallel_3", "classKernel_1_1AreParallel__3.html", [
      [ "operator()", "classKernel_1_1AreParallel__3.html#a36548de4a1d83772b01829b491d06dbb", null ],
      [ "operator()", "classKernel_1_1AreParallel__3.html#a00ecef03cd35745248d2769ee3d711ad", null ],
      [ "operator()", "classKernel_1_1AreParallel__3.html#a23ec56d66f53ebcac1b9e385dea36602", null ],
      [ "operator()", "classKernel_1_1AreParallel__3.html#a7eff828ac900e9f28ef3104089dafb32", null ]
    ] ],
    [ "Kernel::AreStrictlyOrderedAlongLine_2", "classKernel_1_1AreStrictlyOrderedAlongLine__2.html", [
      [ "operator()", "classKernel_1_1AreStrictlyOrderedAlongLine__2.html#a1559dec14ff5f4571120183cd4e9c73e", null ]
    ] ],
    [ "Kernel::AreStrictlyOrderedAlongLine_3", "classKernel_1_1AreStrictlyOrderedAlongLine__3.html", [
      [ "operator()", "classKernel_1_1AreStrictlyOrderedAlongLine__3.html#afa0edfddfa7bb375ffb32042eb4f9125", null ]
    ] ],
    [ "Kernel::Assign_2", "classKernel_1_1Assign__2.html", [
      [ "operator()", "classKernel_1_1Assign__2.html#aac0a5371c86898f7f07ebf69def999b2", null ]
    ] ],
    [ "Kernel::Assign_3", "classKernel_1_1Assign__3.html", [
      [ "operator()", "classKernel_1_1Assign__3.html#a36f27d9221caa056e6c28eae475ef3e0", null ]
    ] ],
    [ "Kernel::BoundedSide_2", "classKernel_1_1BoundedSide__2.html", [
      [ "operator()", "classKernel_1_1BoundedSide__2.html#a086badcc69e0d154eb32cf8bf619b6e8", null ],
      [ "operator()", "classKernel_1_1BoundedSide__2.html#a5465e99a2054d84b1c3f2fded26ea178", null ],
      [ "operator()", "classKernel_1_1BoundedSide__2.html#ab4726672aa5ce591f4ae9f0ac6103a5a", null ]
    ] ],
    [ "Kernel::BoundedSide_3", "classKernel_1_1BoundedSide__3.html", [
      [ "operator()", "classKernel_1_1BoundedSide__3.html#ad8d55c8294d3e4df59c4189d85ab7a89", null ],
      [ "operator()", "classKernel_1_1BoundedSide__3.html#adb68f9302e4e28904c15abda4c8b45e7", null ],
      [ "operator()", "classKernel_1_1BoundedSide__3.html#aa310226fbe23ec6520c257038a8007c2", null ]
    ] ],
    [ "Kernel::CartesianConstIterator_2", "classKernel_1_1CartesianConstIterator__2.html", null ],
    [ "Kernel::CartesianConstIterator_3", "classKernel_1_1CartesianConstIterator__3.html", null ],
    [ "Kernel::CollinearAreOrderedAlongLine_2", "classKernel_1_1CollinearAreOrderedAlongLine__2.html", [
      [ "operator()", "classKernel_1_1CollinearAreOrderedAlongLine__2.html#aaac3273983f7f020b7b90b2fa4d42d48", null ]
    ] ],
    [ "Kernel::CollinearAreOrderedAlongLine_3", "classKernel_1_1CollinearAreOrderedAlongLine__3.html", [
      [ "operator()", "classKernel_1_1CollinearAreOrderedAlongLine__3.html#a4071a869cc68e4115f3647cd0bc77a3b", null ]
    ] ],
    [ "Kernel::CollinearAreStrictlyOrderedAlongLine_2", "classKernel_1_1CollinearAreStrictlyOrderedAlongLine__2.html", [
      [ "operator()", "classKernel_1_1CollinearAreStrictlyOrderedAlongLine__2.html#a556cfcb3da5aeac088d49f445e856037", null ]
    ] ],
    [ "Kernel::CollinearAreStrictlyOrderedAlongLine_3", "classKernel_1_1CollinearAreStrictlyOrderedAlongLine__3.html", [
      [ "operator()", "classKernel_1_1CollinearAreStrictlyOrderedAlongLine__3.html#aecc78d25f22373c5be76c527215d15dd", null ]
    ] ],
    [ "Kernel::CollinearHasOn_2", "classKernel_1_1CollinearHasOn__2.html", [
      [ "operator()", "classKernel_1_1CollinearHasOn__2.html#a91b0efea5b74fed767fc82d78f4e9419", null ],
      [ "operator()", "classKernel_1_1CollinearHasOn__2.html#a2e3ba942326d447c9606c9dc405a7983", null ]
    ] ],
    [ "Kernel::Collinear_2", "classKernel_1_1Collinear__2.html", [
      [ "operator()", "classKernel_1_1Collinear__2.html#a7ec8f07436ff7dd53c407dad397c4d58", null ]
    ] ],
    [ "Kernel::Collinear_3", "classKernel_1_1Collinear__3.html", [
      [ "operator()", "classKernel_1_1Collinear__3.html#a59ee8766eee76dc50852efe1188c9788", null ]
    ] ],
    [ "Kernel::CompareAngleWithXAxis_2", "classKernel_1_1CompareAngleWithXAxis__2.html", [
      [ "operator()", "classKernel_1_1CompareAngleWithXAxis__2.html#ac59c23215bcbba1a45e947c611ce7f35", null ]
    ] ],
    [ "Kernel::CompareAngle_3", "classKernel_1_1CompareAngle__3.html", [
      [ "operator()", "classKernel_1_1CompareAngle__3.html#ab25a6d5d07f50b09b8ef46b4ef114422", null ],
      [ "operator()", "classKernel_1_1CompareAngle__3.html#a909b74740ed5d19e1e7e2e2d0ea113f9", null ],
      [ "operator()", "classKernel_1_1CompareAngle__3.html#a8d9db055c3a7eedb34b1f27d4eac6a6d", null ]
    ] ],
    [ "Kernel::CompareDihedralAngle_3", "classKernel_1_1CompareDihedralAngle__3.html", [
      [ "operator()", "classKernel_1_1CompareDihedralAngle__3.html#aa253423e8bec9175b0ce214e9fc57ce9", null ],
      [ "operator()", "classKernel_1_1CompareDihedralAngle__3.html#a1309d6f4fc962b410eff4d06ea9cce02", null ],
      [ "operator()", "classKernel_1_1CompareDihedralAngle__3.html#ae145a48598f99b62d0e007590633bbf1", null ],
      [ "operator()", "classKernel_1_1CompareDihedralAngle__3.html#a72918f371bb10f1de17f59ebbbd0be93", null ]
    ] ],
    [ "Kernel::CompareDistance_2", "classKernel_1_1CompareDistance__2.html", [
      [ "operator()", "classKernel_1_1CompareDistance__2.html#a90e055db9d0fc8d931f2f7ac9572c1c8", null ],
      [ "operator()", "classKernel_1_1CompareDistance__2.html#a929cb5a19659e95d1e878efc26749d15", null ]
    ] ],
    [ "Kernel::CompareDistance_3", "classKernel_1_1CompareDistance__3.html", [
      [ "operator()", "classKernel_1_1CompareDistance__3.html#a9312303e0c1412aa981b1eaa83d597f5", null ],
      [ "operator()", "classKernel_1_1CompareDistance__3.html#a2ee64f4b6e1ac24eab6935efcf9d22ca", null ]
    ] ],
    [ "Kernel::ComparePowerDistance_2", "classKernel_1_1ComparePowerDistance__2.html", [
      [ "operator()", "classKernel_1_1ComparePowerDistance__2.html#abe86bb6b26894a0545a4068d16879ed0", null ]
    ] ],
    [ "Kernel::ComparePowerDistance_3", "classKernel_1_1ComparePowerDistance__3.html", [
      [ "operator()", "classKernel_1_1ComparePowerDistance__3.html#a4c74dd7e4581caefd03e3f3efbce4988", null ]
    ] ],
    [ "Kernel::CompareSignedDistanceToLine_2", "classKernel_1_1CompareSignedDistanceToLine__2.html", [
      [ "operator()", "classKernel_1_1CompareSignedDistanceToLine__2.html#a06ae3a7d6fe36e30138952d1529e61de", null ],
      [ "operator()", "classKernel_1_1CompareSignedDistanceToLine__2.html#a2700c56d7f2be4346a01c3a932b93dd3", null ]
    ] ],
    [ "Kernel::CompareSlope_2", "classKernel_1_1CompareSlope__2.html", [
      [ "operator()", "classKernel_1_1CompareSlope__2.html#ad7dc0c96020253fae931f3235c018bd0", null ],
      [ "operator()", "classKernel_1_1CompareSlope__2.html#af2855a74b3500a2b16ecd76f516a034d", null ],
      [ "operator()", "classKernel_1_1CompareSlope__2.html#a31392050cebd89f10f1c8fb33ec290ab", null ]
    ] ],
    [ "Kernel::CompareSlope_3", "classKernel_1_1CompareSlope__3.html", [
      [ "operator()", "classKernel_1_1CompareSlope__3.html#a1c974113436dfe09aabcbc03ae1f65e0", null ]
    ] ],
    [ "Kernel::CompareSquaredDistance_2", "classKernel_1_1CompareSquaredDistance__2.html", [
      [ "operator()", "classKernel_1_1CompareSquaredDistance__2.html#a9c39337c2107c2ea4d724010b1124749", null ]
    ] ],
    [ "Kernel::CompareSquaredDistance_3", "classKernel_1_1CompareSquaredDistance__3.html", [
      [ "operator()", "classKernel_1_1CompareSquaredDistance__3.html#a9d18108278fde42d2a2dd8ddf0382c11", null ]
    ] ],
    [ "Kernel::CompareSquaredRadius_3", "classKernel_1_1CompareSquaredRadius__3.html", [
      [ "operator()", "classKernel_1_1CompareSquaredRadius__3.html#aa91cbf2115e8791f3b03407558f894ef", null ],
      [ "operator()", "classKernel_1_1CompareSquaredRadius__3.html#a05dd7dadfbd3faf185144585c123d85e", null ],
      [ "operator()", "classKernel_1_1CompareSquaredRadius__3.html#a9eab8876a09b1c64d00fcbfc4cb267d7", null ],
      [ "operator()", "classKernel_1_1CompareSquaredRadius__3.html#a8d7dfb7219b73a3e0d8d1ea5b3e37dd1", null ]
    ] ],
    [ "Kernel::CompareWeightedSquaredRadius_3", "classKernel_1_1CompareWeightedSquaredRadius__3.html", [
      [ "operator()", "classKernel_1_1CompareWeightedSquaredRadius__3.html#a0aaba811f933c5881a7be7ccacb22a3f", null ],
      [ "operator()", "classKernel_1_1CompareWeightedSquaredRadius__3.html#ab09a7575da7a5ce27c9a12852eb84aff", null ],
      [ "operator()", "classKernel_1_1CompareWeightedSquaredRadius__3.html#a361736e136fdbd4f607b2d8210044674", null ],
      [ "operator()", "classKernel_1_1CompareWeightedSquaredRadius__3.html#aaaf829606929899bdaac2c18692f6358", null ]
    ] ],
    [ "Kernel::CompareXAtY_2", "classKernel_1_1CompareXAtY__2.html", [
      [ "operator()", "classKernel_1_1CompareXAtY__2.html#a6c86f55ac44f50d0ec13e7ad800c0339", null ],
      [ "operator()", "classKernel_1_1CompareXAtY__2.html#a79f920422213b9addce46f41e8963b3c", null ],
      [ "operator()", "classKernel_1_1CompareXAtY__2.html#adc4a95f961de5558931371bb1fc422b4", null ],
      [ "operator()", "classKernel_1_1CompareXAtY__2.html#a447c19283a0027dbeaac344ca48bdada", null ]
    ] ],
    [ "Kernel::CompareXYZ_3", "classKernel_1_1CompareXYZ__3.html", [
      [ "operator()", "classKernel_1_1CompareXYZ__3.html#a0043bb3ba9b29cf9948e051f5698f39c", null ]
    ] ],
    [ "Kernel::CompareXY_2", "classKernel_1_1CompareXY__2.html", [
      [ "operator()", "classKernel_1_1CompareXY__2.html#aa45fe5bcc91fdfc8626d7fa7111b521c", null ]
    ] ],
    [ "Kernel::CompareXY_3", "classKernel_1_1CompareXY__3.html", [
      [ "operator()", "classKernel_1_1CompareXY__3.html#a19b0a6c060f90110611385255b4471a9", null ]
    ] ],
    [ "Kernel::CompareX_2", "classKernel_1_1CompareX__2.html", [
      [ "operator()", "classKernel_1_1CompareX__2.html#a54794a38c701fe6931afd42919df0334", null ],
      [ "operator()", "classKernel_1_1CompareX__2.html#a4d8b68d2337e6d8c3c812d64f7e4474c", null ],
      [ "operator()", "classKernel_1_1CompareX__2.html#a99377411446d95f821a48c29e4da8207", null ],
      [ "operator()", "classKernel_1_1CompareX__2.html#a07127b3d58bd9453033b4a4abb004bbb", null ]
    ] ],
    [ "Kernel::CompareX_3", "classKernel_1_1CompareX__3.html", [
      [ "operator()", "classKernel_1_1CompareX__3.html#a2e0f86874f36982ca14dcec4489c8395", null ]
    ] ],
    [ "Kernel::CompareYAtX_2", "classKernel_1_1CompareYAtX__2.html", [
      [ "operator()", "classKernel_1_1CompareYAtX__2.html#a9ead49e798d4a802e30a6374db304439", null ],
      [ "operator()", "classKernel_1_1CompareYAtX__2.html#a27b7944ceab26bf24186e5bb1a808d47", null ],
      [ "operator()", "classKernel_1_1CompareYAtX__2.html#a18c0ef789b19738972dd0bac6d039bbb", null ],
      [ "operator()", "classKernel_1_1CompareYAtX__2.html#a63ab598617c0997eaf50e615c6218f33", null ],
      [ "operator()", "classKernel_1_1CompareYAtX__2.html#aee5b8d6c0f38a7326eb3ee7a5ad0f996", null ],
      [ "operator()", "classKernel_1_1CompareYAtX__2.html#aec05d3911f4f01cd8c52765b7f4d597d", null ]
    ] ],
    [ "Kernel::CompareYX_2", "classKernel_1_1CompareYX__2.html", [
      [ "operator()", "classKernel_1_1CompareYX__2.html#a51a00839fdb5fa76bede856f8ba46e4b", null ]
    ] ],
    [ "Kernel::CompareY_2", "classKernel_1_1CompareY__2.html", [
      [ "operator()", "classKernel_1_1CompareY__2.html#a9d501abc49e20cc3cabee87c48bd2952", null ],
      [ "operator()", "classKernel_1_1CompareY__2.html#a762d1bf35a3d3df34dc4c5814acbed82", null ],
      [ "operator()", "classKernel_1_1CompareY__2.html#afc4684a4a0cea42e4604e34394232397", null ],
      [ "operator()", "classKernel_1_1CompareY__2.html#a674c4fc049e3c2122ccc3c365c55c268", null ]
    ] ],
    [ "Kernel::CompareY_3", "classKernel_1_1CompareY__3.html", [
      [ "operator()", "classKernel_1_1CompareY__3.html#ab7f74a7c6afbeec8f756dba5134e8222", null ]
    ] ],
    [ "Kernel::CompareZ_3", "classKernel_1_1CompareZ__3.html", [
      [ "operator()", "classKernel_1_1CompareZ__3.html#ac394d0a02988a869633d84143a1de8bf", null ]
    ] ],
    [ "Kernel::ComputeA_2", "classKernel_1_1ComputeA__2.html", [
      [ "operator()", "classKernel_1_1ComputeA__2.html#abe1dfae8102b529cc2032118ceb82361", null ]
    ] ],
    [ "Kernel::ComputeA_3", "classKernel_1_1ComputeA__3.html", [
      [ "operator()", "classKernel_1_1ComputeA__3.html#a6cf15c0877eb947af1c99c8a1a58d9c9", null ]
    ] ],
    [ "Kernel::ComputeApproximateArea_3", "classKernel_1_1ComputeApproximateArea__3.html", [
      [ "operator()", "classKernel_1_1ComputeApproximateArea__3.html#a587bcaaac0d89c7ad6f6ba806a24b1c1", null ]
    ] ],
    [ "Kernel::ComputeApproximateAngle_3", "classKernel_1_1ComputeApproximateAngle__3.html", [
      [ "operator()", "classKernel_1_1ComputeApproximateAngle__3.html#a493135c37d1480cfcb80e5ebb46f61f9", null ],
      [ "operator()", "classKernel_1_1ComputeApproximateAngle__3.html#a105dfa2cec87896ff870ca8e7f8ecd54", null ]
    ] ],
    [ "Kernel::ComputeApproximateDihedralAngle_3", "classKernel_1_1ComputeApproximateDihedralAngle__3.html", [
      [ "operator()", "classKernel_1_1ComputeApproximateDihedralAngle__3.html#a8bef04b9470d39a35f017c19497b8e54", null ]
    ] ],
    [ "Kernel::ComputeApproximateSquaredLength_3", "classKernel_1_1ComputeApproximateSquaredLength__3.html", [
      [ "operator()", "classKernel_1_1ComputeApproximateSquaredLength__3.html#a6327a1575c25db61de7fe7eb409ea00f", null ]
    ] ],
    [ "Kernel::ComputeAreaDividedByPi_3", "classKernel_1_1ComputeAreaDividedByPi__3.html", [
      [ "operator()", "classKernel_1_1ComputeAreaDividedByPi__3.html#ade0ff58bb2135c61713b22f4ef29a38a", null ]
    ] ],
    [ "Kernel::ComputeArea_2", "classKernel_1_1ComputeArea__2.html", [
      [ "operator()", "classKernel_1_1ComputeArea__2.html#ac9805310672bae715b5af725de2e7f22", null ],
      [ "operator()", "classKernel_1_1ComputeArea__2.html#aa975e6931b54650389c60279a0b776e0", null ],
      [ "operator()", "classKernel_1_1ComputeArea__2.html#ad6e5e07e2538ec6f6ef11bf3f0f34f47", null ]
    ] ],
    [ "Kernel::ComputeArea_3", "classKernel_1_1ComputeArea__3.html", [
      [ "operator()", "classKernel_1_1ComputeArea__3.html#a22596084ab39cf5c7c67024d1fb9aec9", null ],
      [ "operator()", "classKernel_1_1ComputeArea__3.html#ab69f07bfd58f02c5a6ae84b52d6d9b8f", null ]
    ] ],
    [ "Kernel::ComputeB_2", "classKernel_1_1ComputeB__2.html", [
      [ "operator()", "classKernel_1_1ComputeB__2.html#aa2aee035eb9f0d31a8d2cb6284147592", null ]
    ] ],
    [ "Kernel::ComputeB_3", "classKernel_1_1ComputeB__3.html", [
      [ "operator()", "classKernel_1_1ComputeB__3.html#aba73a31ba223bcd8a46b7870ef42d589", null ]
    ] ],
    [ "Kernel::ComputeC_2", "classKernel_1_1ComputeC__2.html", [
      [ "operator()", "classKernel_1_1ComputeC__2.html#a49a2cdb38e65393824dcd102213bbaca", null ]
    ] ],
    [ "Kernel::ComputeC_3", "classKernel_1_1ComputeC__3.html", [
      [ "operator()", "classKernel_1_1ComputeC__3.html#a051a9f8bc3e2b2e21c49b992bef43836", null ]
    ] ],
    [ "Kernel::ComputeD_3", "classKernel_1_1ComputeD__3.html", [
      [ "operator()", "classKernel_1_1ComputeD__3.html#a35fc702236238f1c658dd0aa8a3ec33a", null ]
    ] ],
    [ "Kernel::ComputeDeterminant_2", "classKernel_1_1ComputeDeterminant__2.html", [
      [ "operator()", "classKernel_1_1ComputeDeterminant__2.html#adeb7055897984f1602c902c6fcd7a533", null ]
    ] ],
    [ "Kernel::ComputeDeterminant_3", "classKernel_1_1ComputeDeterminant__3.html", [
      [ "operator()", "classKernel_1_1ComputeDeterminant__3.html#af5b4850e84385bf1acb23cc8617f482b", null ]
    ] ],
    [ "Kernel::ComputeDx_2", "classKernel_1_1ComputeDx__2.html", [
      [ "operator()", "classKernel_1_1ComputeDx__2.html#aff174d79fed58b66764e7218bd4a37ef", null ]
    ] ],
    [ "Kernel::ComputeDx_3", "classKernel_1_1ComputeDx__3.html", [
      [ "operator()", "classKernel_1_1ComputeDx__3.html#a66a0e0cb96c199ec643eaed47c880c10", null ]
    ] ],
    [ "Kernel::ComputeDy_2", "classKernel_1_1ComputeDy__2.html", [
      [ "operator()", "classKernel_1_1ComputeDy__2.html#ab4052ddce9c5c212c58a3b185761dd08", null ]
    ] ],
    [ "Kernel::ComputeDy_3", "classKernel_1_1ComputeDy__3.html", [
      [ "operator()", "classKernel_1_1ComputeDy__3.html#a8630b0cb61d33ff3315a4f772fba65bb", null ]
    ] ],
    [ "Kernel::ComputeDz_3", "classKernel_1_1ComputeDz__3.html", [
      [ "operator()", "classKernel_1_1ComputeDz__3.html#aafe4756af7078e314baa2e25a564deb9", null ]
    ] ],
    [ "Kernel::ComputeHx_2", "classKernel_1_1ComputeHx__2.html", [
      [ "operator()", "classKernel_1_1ComputeHx__2.html#a44aacd540ce9b55f8760cab6cffcd247", null ],
      [ "operator()", "classKernel_1_1ComputeHx__2.html#ab836a1050457cf5aaf8ea18ef471949a", null ]
    ] ],
    [ "Kernel::ComputeHx_3", "classKernel_1_1ComputeHx__3.html", [
      [ "operator()", "classKernel_1_1ComputeHx__3.html#a63fcc7acc768beee0d2dcbcf214b6c3b", null ],
      [ "operator()", "classKernel_1_1ComputeHx__3.html#ad92a65d3da396d1f58b3fc0092aa8a6c", null ]
    ] ],
    [ "Kernel::ComputeHy_2", "classKernel_1_1ComputeHy__2.html", [
      [ "operator()", "classKernel_1_1ComputeHy__2.html#a170530668b97dea45ecb9977006e4874", null ],
      [ "operator()", "classKernel_1_1ComputeHy__2.html#a15fbc1fac0e33f15bad3cee67e437221", null ]
    ] ],
    [ "Kernel::ComputeHy_3", "classKernel_1_1ComputeHy__3.html", [
      [ "operator()", "classKernel_1_1ComputeHy__3.html#ac5711a7158fd77ed2e8be9172861c608", null ],
      [ "operator()", "classKernel_1_1ComputeHy__3.html#af80dfad5abc2bcf56c1811f683bc87f3", null ]
    ] ],
    [ "Kernel::ComputeHw_2", "classKernel_1_1ComputeHw__2.html", [
      [ "operator()", "classKernel_1_1ComputeHw__2.html#a7a4f4a053d3a6692f649df7b01d006a1", null ],
      [ "operator()", "classKernel_1_1ComputeHw__2.html#a506bb696fd3f68b6a219cd3582934a98", null ]
    ] ],
    [ "Kernel::ComputeHw_3", "classKernel_1_1ComputeHw__3.html", [
      [ "operator()", "classKernel_1_1ComputeHw__3.html#afb497caf070b6753f84f6f6a6663b96c", null ],
      [ "operator()", "classKernel_1_1ComputeHw__3.html#a9edd9aba56d45c154893dfb2dd5d433f", null ]
    ] ],
    [ "Kernel::ComputeHz_3", "classKernel_1_1ComputeHz__3.html", [
      [ "operator()", "classKernel_1_1ComputeHz__3.html#a686f819fff3ae466e6697a9ae27954de", null ],
      [ "operator()", "classKernel_1_1ComputeHz__3.html#aa55b2589a5064f88f43eb21bfe9bdc5b", null ]
    ] ],
    [ "Kernel::ComputePowerDistanceToPowerSphere_3", "classKernel_1_1ComputePowerDistanceToPowerSphere__3.html", [
      [ "operator()", "classKernel_1_1ComputePowerDistanceToPowerSphere__3.html#a79b0af312b011da590688825a5bd8be9", null ]
    ] ],
    [ "Kernel::ComputePowerProduct_2", "classKernel_1_1ComputePowerProduct__2.html", [
      [ "operator()", "classKernel_1_1ComputePowerProduct__2.html#a5aa5369980b1df3ef49dd15868b2b4e8", null ]
    ] ],
    [ "Kernel::ComputePowerProduct_3", "classKernel_1_1ComputePowerProduct__3.html", [
      [ "operator()", "classKernel_1_1ComputePowerProduct__3.html#a5564ff8157782c91589302e3445a157c", null ]
    ] ],
    [ "Kernel::ComputeLInfinityDistance_2", "classKernel_1_1ComputeLInfinityDistance__2.html", [
      [ "operator()", "classKernel_1_1ComputeLInfinityDistance__2.html#a1ea4f9487c6bd1bea583018c16a99e58", null ]
    ] ],
    [ "Kernel::ComputeLInfinityDistance_3", "classKernel_1_1ComputeLInfinityDistance__3.html", [
      [ "operator()", "classKernel_1_1ComputeLInfinityDistance__3.html#ab613d2bfec067ab200a969407ace7de0", null ]
    ] ],
    [ "Kernel::ComputeScalarProduct_2", "classKernel_1_1ComputeScalarProduct__2.html", [
      [ "operator()", "classKernel_1_1ComputeScalarProduct__2.html#a3c47639c8a9256df4a1d5a78cc800764", null ]
    ] ],
    [ "Kernel::ComputeScalarProduct_3", "classKernel_1_1ComputeScalarProduct__3.html", [
      [ "operator()", "classKernel_1_1ComputeScalarProduct__3.html#a817539049318ed24cb61928ce01012e7", null ]
    ] ],
    [ "Kernel::ComputeSquaredArea_3", "classKernel_1_1ComputeSquaredArea__3.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredArea__3.html#aec0b63518de63cb51fdb3bdb49279227", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredArea__3.html#ae16ed1e2e12662ba85f00e92cc4a6029", null ]
    ] ],
    [ "Kernel::ComputeSquaredDistance_2", "classKernel_1_1ComputeSquaredDistance__2.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredDistance__2.html#ae451eda5afcef71efcb128c9b978dcf5", null ]
    ] ],
    [ "Kernel::ComputeSquaredDistance_3", "classKernel_1_1ComputeSquaredDistance__3.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredDistance__3.html#aed2fff0e8fb3a5f40c209bb58dae8069", null ]
    ] ],
    [ "Kernel::ComputeSquaredLengthDividedByPiSquare_3", "classKernel_1_1ComputeSquaredLengthDividedByPiSquare__3.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredLengthDividedByPiSquare__3.html#a09674ab2d2fecca66ca09751e17d0df2", null ]
    ] ],
    [ "Kernel::ComputeSquaredLength_2", "classKernel_1_1ComputeSquaredLength__2.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredLength__2.html#a2ea5af9fc98d16f993c93be6a655dddb", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredLength__2.html#ad8f0b591f9181f2f4d03db7de049b28a", null ]
    ] ],
    [ "Kernel::ComputeSquaredLength_3", "classKernel_1_1ComputeSquaredLength__3.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredLength__3.html#aceab22457752ff8df3fd7d09b13b7c31", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredLength__3.html#a98b5f34095316f4062096af83edb5e5b", null ]
    ] ],
    [ "Kernel::ComputeSquaredRadius_2", "classKernel_1_1ComputeSquaredRadius__2.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__2.html#a4285a35d2bc59fc497faf77405202faa", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__2.html#af65b0eea28e6c45a64501db4565c361c", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__2.html#a76215f7d5a6da13200dca4b3daa3fee1", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__2.html#a30731ea8f3b8438e6a0b772a3aa30bfa", null ]
    ] ],
    [ "Kernel::ComputeSquaredRadius_3", "classKernel_1_1ComputeSquaredRadius__3.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__3.html#ad4edaefd24ec9dad1eb2cc23bb0e8df3", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__3.html#add3dc17f5adfb4737e68887a4201d404", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__3.html#a248284447edc1be233839a8f70379f51", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__3.html#abdc899e5baaa377b8fb7c66af26597bc", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__3.html#a284c3c3b0d66abe1585a6b6093c42e7c", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadius__3.html#ac605cadaafe388c7ee0399bdd05c5cfd", null ]
    ] ],
    [ "Kernel::ComputeSquaredRadiusSmallestOrthogonalCircle_2", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html#ad3ddce1b9ddebebd000380137a6c02ad", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html#a94466bb8c2dfe149e0c22514bb9824ea", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalCircle__2.html#a31f5c389188861678c9d89281c7d4c59", null ]
    ] ],
    [ "Kernel::ComputeSquaredRadiusSmallestOrthogonalSphere_3", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html", [
      [ "operator()", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a5f693db27e0c576b4c4e3e204c956f62", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a53cf045adf5a892d16fa20348f71a14a", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a9ad9adc320f4a4d24337bcb081f0eec2", null ],
      [ "operator()", "classKernel_1_1ComputeSquaredRadiusSmallestOrthogonalSphere__3.html#a949acfc065c474afdf964be5cfcc9a6f", null ]
    ] ],
    [ "Kernel::ComputeVolume_3", "classKernel_1_1ComputeVolume__3.html", [
      [ "operator()", "classKernel_1_1ComputeVolume__3.html#a74e33e215c888bf11f5fbe40241ac831", null ],
      [ "operator()", "classKernel_1_1ComputeVolume__3.html#a138e1f41d22655f052e249ca415e3418", null ],
      [ "operator()", "classKernel_1_1ComputeVolume__3.html#a617d129f99def4c454ae94b475cf6e81", null ]
    ] ],
    [ "Kernel::ComputeWeight_2", "classKernel_1_1ComputeWeight__2.html", [
      [ "operator()", "classKernel_1_1ComputeWeight__2.html#a98da75c6327155024c533907e7af0961", null ]
    ] ],
    [ "Kernel::ComputeWeight_3", "classKernel_1_1ComputeWeight__3.html", [
      [ "operator()", "classKernel_1_1ComputeWeight__3.html#a81838be1cb3c96c3f267162121a3b9b6", null ]
    ] ],
    [ "Kernel::ComputeX_2", "classKernel_1_1ComputeX__2.html", [
      [ "operator()", "classKernel_1_1ComputeX__2.html#ab790f8d36ba684507bfbb815b1d6fa83", null ],
      [ "operator()", "classKernel_1_1ComputeX__2.html#a3da8f089f3fcb5e97de0150cfed2f945", null ]
    ] ],
    [ "Kernel::ComputeX_3", "classKernel_1_1ComputeX__3.html", [
      [ "operator()", "classKernel_1_1ComputeX__3.html#afa7271cb826779554b55f6c9bf8a4083", null ],
      [ "operator()", "classKernel_1_1ComputeX__3.html#add303b1a6b28e7eb1bcd6eacedb872f2", null ]
    ] ],
    [ "Kernel::ComputeXmax_2", "classKernel_1_1ComputeXmax__2.html", [
      [ "operator()", "classKernel_1_1ComputeXmax__2.html#a2e33e6caa6cffa03d0e3c0c60ed4e645", null ]
    ] ],
    [ "Kernel::ComputeXmax_3", "classKernel_1_1ComputeXmax__3.html", [
      [ "operator()", "classKernel_1_1ComputeXmax__3.html#aafff4c2a2ec07b26643fd71eb3b4c3b0", null ]
    ] ],
    [ "Kernel::ComputeXmin_2", "classKernel_1_1ComputeXmin__2.html", [
      [ "operator()", "classKernel_1_1ComputeXmin__2.html#a19ea7ec7ccda86aec464736e211d200e", null ]
    ] ],
    [ "Kernel::ComputeXmin_3", "classKernel_1_1ComputeXmin__3.html", [
      [ "operator()", "classKernel_1_1ComputeXmin__3.html#ab7aea420ecebdc0c1bff6ab2637e8855", null ]
    ] ],
    [ "Kernel::ComputeYAtX_2", "classKernel_1_1ComputeYAtX__2.html", [
      [ "operator()", "classKernel_1_1ComputeYAtX__2.html#adc2752111d1684046aef4e4677e50762", null ]
    ] ],
    [ "Kernel::ComputeY_2", "classKernel_1_1ComputeY__2.html", [
      [ "operator()", "classKernel_1_1ComputeY__2.html#a3cda8f88c980ceb43e9c6845425475b7", null ],
      [ "operator()", "classKernel_1_1ComputeY__2.html#a89c640bb1fae43d642ce5da0b7689f34", null ]
    ] ],
    [ "Kernel::ComputeY_3", "classKernel_1_1ComputeY__3.html", [
      [ "operator()", "classKernel_1_1ComputeY__3.html#aad926f3adc6f1e6325389c189defebbf", null ],
      [ "operator()", "classKernel_1_1ComputeY__3.html#a82102e1aef97fc753cb64143e0fd84fd", null ]
    ] ],
    [ "Kernel::ComputeYmax_2", "classKernel_1_1ComputeYmax__2.html", [
      [ "operator()", "classKernel_1_1ComputeYmax__2.html#ad1fa85aec2820f3acf0b47c994e12050", null ]
    ] ],
    [ "Kernel::ComputeYmax_3", "classKernel_1_1ComputeYmax__3.html", [
      [ "operator()", "classKernel_1_1ComputeYmax__3.html#a654039e1ba87d4206c0ad45eb40a63c4", null ]
    ] ],
    [ "Kernel::ComputeYmin_2", "classKernel_1_1ComputeYmin__2.html", [
      [ "operator()", "classKernel_1_1ComputeYmin__2.html#ad3bfec422fcaf85a1591d3d705687b09", null ]
    ] ],
    [ "Kernel::ComputeYmin_3", "classKernel_1_1ComputeYmin__3.html", [
      [ "operator()", "classKernel_1_1ComputeYmin__3.html#a9935e48e6807d8275cc64131cc3183c8", null ]
    ] ],
    [ "Kernel::ComputeZ_3", "classKernel_1_1ComputeZ__3.html", [
      [ "operator()", "classKernel_1_1ComputeZ__3.html#adfcdae29599ac918f83120bd51cca716", null ],
      [ "operator()", "classKernel_1_1ComputeZ__3.html#aa24740a5cfd4ae62a5dbd1f109725a8a", null ]
    ] ],
    [ "Kernel::ComputeZmax_3", "classKernel_1_1ComputeZmax__3.html", [
      [ "operator()", "classKernel_1_1ComputeZmax__3.html#a6bf236be1d834c6c37bacf8b0b79f6f7", null ]
    ] ],
    [ "Kernel::ComputeZmin_3", "classKernel_1_1ComputeZmin__3.html", [
      [ "operator()", "classKernel_1_1ComputeZmin__3.html#a52761ecf79fe59c931abb6fca9dde068", null ]
    ] ],
    [ "Kernel::ConstructBarycenter_2", "classKernel_1_1ConstructBarycenter__2.html", [
      [ "operator()", "classKernel_1_1ConstructBarycenter__2.html#ac0906596ae0fb8e92a25926b603d6682", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__2.html#a318e129662a75b2d9fb1ff5d07029044", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__2.html#aa9986f05e5c020a6863cf5616d97ca4c", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__2.html#a338475ec0d324c9aaef6655ca0de4f2b", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__2.html#ad737fe053804b312a199d808f0735c99", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__2.html#aa9606532db9642c44e32bac442fa2561", null ]
    ] ],
    [ "Kernel::ConstructBarycenter_3", "classKernel_1_1ConstructBarycenter__3.html", [
      [ "operator()", "classKernel_1_1ConstructBarycenter__3.html#ab69e58310f17aeabf4c21b7187838ef7", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__3.html#a01f2f1c8ff891fb9236bc58fb241cf28", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__3.html#ab50a93a3e4ffce05833f6ac84e4755be", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__3.html#ae0f035b4e164a7bbb6b8ea9ccfbd508b", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__3.html#af9676ac7ceb046cc5ce421f8149faba3", null ],
      [ "operator()", "classKernel_1_1ConstructBarycenter__3.html#afd479836b1bc1c1842d32d0d2c93b7ca", null ]
    ] ],
    [ "Kernel::ConstructBaseVector_3", "classKernel_1_1ConstructBaseVector__3.html", [
      [ "operator()", "classKernel_1_1ConstructBaseVector__3.html#ab17a1a6fcbc531d479501aee42a93e02", null ]
    ] ],
    [ "Kernel::ConstructBbox_2", "classKernel_1_1ConstructBbox__2.html", [
      [ "operator()", "classKernel_1_1ConstructBbox__2.html#a323f6ca417d63c404aa70e09f7ad49fb", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__2.html#a226eaa8167251060c6ef9bb6e080516f", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__2.html#a7d478bc918e7709d403c69e9e727a49c", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__2.html#a274ba2098944460505a970bafc2e211e", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__2.html#abe2627faa77bfc13a76137bde93ef671", null ]
    ] ],
    [ "Kernel::ConstructBbox_3", "classKernel_1_1ConstructBbox__3.html", [
      [ "operator()", "classKernel_1_1ConstructBbox__3.html#abaf0ce6c6f1aedc787da9434615464d3", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__3.html#a01575e1554ad26e42d098952f17a67c2", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__3.html#a7326d59c737f8d8c47fb1077cd97389e", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__3.html#a1a3531f1ac37a8b9b54afb40cb313a73", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__3.html#abed0c0b935a31ea7d2538ca9de8daf85", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__3.html#a8962a24614feac2134c4d10d4211b1db", null ],
      [ "operator()", "classKernel_1_1ConstructBbox__3.html#ac6e6ba1caccc854e58d5702be7a332c6", null ]
    ] ],
    [ "Kernel::ConstructBisector_2", "classKernel_1_1ConstructBisector__2.html", [
      [ "operator()", "classKernel_1_1ConstructBisector__2.html#a879267dfb97a5e44f3b7ec3411d867cd", null ],
      [ "operator()", "classKernel_1_1ConstructBisector__2.html#ac63c11941c834d2fa34cedfd142cff0c", null ]
    ] ],
    [ "Kernel::ConstructBisector_3", "classKernel_1_1ConstructBisector__3.html", [
      [ "operator()", "classKernel_1_1ConstructBisector__3.html#a1f58b405683701835560351f1e891afe", null ],
      [ "operator()", "classKernel_1_1ConstructBisector__3.html#a86b47d0de509eebc84c7f08dedb6cc2a", null ]
    ] ],
    [ "Kernel::ConstructCartesianConstIterator_2", "classKernel_1_1ConstructCartesianConstIterator__2.html", [
      [ "operator()", "classKernel_1_1ConstructCartesianConstIterator__2.html#a27b1e7bdea7918f245919ffc03fd4da9", null ],
      [ "operator()", "classKernel_1_1ConstructCartesianConstIterator__2.html#ad6c685f6c4480a6d172ec3adb4ce875d", null ],
      [ "operator()", "classKernel_1_1ConstructCartesianConstIterator__2.html#ad56b53394c697c8975bc75ea0998fe68", null ],
      [ "operator()", "classKernel_1_1ConstructCartesianConstIterator__2.html#a7e8b5a3ecb772988ff4f4830fc1b8d3d", null ]
    ] ],
    [ "Kernel::ConstructCartesianConstIterator_3", "classKernel_1_1ConstructCartesianConstIterator__3.html", [
      [ "operator()", "classKernel_1_1ConstructCartesianConstIterator__3.html#a99d4d8154ba75b1dded26daf405b303f", null ],
      [ "operator()", "classKernel_1_1ConstructCartesianConstIterator__3.html#a0ff930c06eb186e70f720591a5dcc24e", null ],
      [ "operator()", "classKernel_1_1ConstructCartesianConstIterator__3.html#a3f35c0019e612b2e62826e5a7edf8767", null ],
      [ "operator()", "classKernel_1_1ConstructCartesianConstIterator__3.html#a272a821591b93776511764c2ccce2e47", null ]
    ] ],
    [ "Kernel::ConstructCenter_2", "classKernel_1_1ConstructCenter__2.html", [
      [ "operator()", "classKernel_1_1ConstructCenter__2.html#ad961d8a9c58d7a0a17da5517562bebd4", null ]
    ] ],
    [ "Kernel::ConstructCenter_3", "classKernel_1_1ConstructCenter__3.html", [
      [ "operator()", "classKernel_1_1ConstructCenter__3.html#a59babfd9a264c1952f61e1eea43e62da", null ],
      [ "operator()", "classKernel_1_1ConstructCenter__3.html#a2452d948133b94b4a8b57025d94d096a", null ]
    ] ],
    [ "Kernel::ConstructCentroid_2", "classKernel_1_1ConstructCentroid__2.html", [
      [ "operator()", "classKernel_1_1ConstructCentroid__2.html#a457e12d765e050e722ebc2b1953debbe", null ],
      [ "operator()", "classKernel_1_1ConstructCentroid__2.html#a74f3f31805d637f1110fefddbc71053a", null ],
      [ "operator()", "classKernel_1_1ConstructCentroid__2.html#a3653267724667bc7dfdf3cb01b12f484", null ]
    ] ],
    [ "Kernel::ConstructCentroid_3", "classKernel_1_1ConstructCentroid__3.html", [
      [ "operator()", "classKernel_1_1ConstructCentroid__3.html#ad0a71f2f045affefbef4fb4acc0e03d7", null ],
      [ "operator()", "classKernel_1_1ConstructCentroid__3.html#a76957498fa7fcb1446e9870011d51ae8", null ],
      [ "operator()", "classKernel_1_1ConstructCentroid__3.html#ad7541695d1249e6a2666c06c44773909", null ],
      [ "operator()", "classKernel_1_1ConstructCentroid__3.html#ad436d8c021c92b195b4046148e054d52", null ]
    ] ],
    [ "Kernel::ConstructCircle_2", "classKernel_1_1ConstructCircle__2.html", [
      [ "operator()", "classKernel_1_1ConstructCircle__2.html#a97d470ea5caf593dfc92542cc3bca2ef", null ],
      [ "operator()", "classKernel_1_1ConstructCircle__2.html#abf1a0e4ef57e5da5cfba0cb5dd46323b", null ],
      [ "operator()", "classKernel_1_1ConstructCircle__2.html#aa2ff1d060daac475e31a1654f25e8f94", null ],
      [ "operator()", "classKernel_1_1ConstructCircle__2.html#af90827bde4f48e28ee21a96aa98511cb", null ]
    ] ],
    [ "Kernel::ConstructCircle_3", "classKernel_1_1ConstructCircle__3.html", [
      [ "operator()", "classKernel_1_1ConstructCircle__3.html#aa28d26af95c4ffab2fc1a911acf70312", null ],
      [ "operator()", "classKernel_1_1ConstructCircle__3.html#a62bdd1f5db2b1c95ceae79496ab49f89", null ],
      [ "operator()", "classKernel_1_1ConstructCircle__3.html#a490ff1bb4508701989e105d4bbd1f50c", null ],
      [ "operator()", "classKernel_1_1ConstructCircle__3.html#a472e822eb29765112b5e0f9f13f04447", null ],
      [ "operator()", "classKernel_1_1ConstructCircle__3.html#ae4dafbded355b382ac6978027119769a", null ],
      [ "operator()", "classKernel_1_1ConstructCircle__3.html#a593010990161fa0a3a6d73d034ffeb08", null ]
    ] ],
    [ "Kernel::ConstructCircumcenter_2", "classKernel_1_1ConstructCircumcenter__2.html", [
      [ "operator()", "classKernel_1_1ConstructCircumcenter__2.html#af3c7e315fd78863f12a0eeacc8f1cf10", null ],
      [ "operator()", "classKernel_1_1ConstructCircumcenter__2.html#a7307f1666c1ce5b0d4221094e89e7f16", null ],
      [ "operator()", "classKernel_1_1ConstructCircumcenter__2.html#a6ed11d98726d44d18d666380eb757b4f", null ]
    ] ],
    [ "Kernel::ConstructCircumcenter_3", "classKernel_1_1ConstructCircumcenter__3.html", [
      [ "operator()", "classKernel_1_1ConstructCircumcenter__3.html#a81db24d7be356a62929509b085df1562", null ],
      [ "operator()", "classKernel_1_1ConstructCircumcenter__3.html#af3a920bc4e8834a29b3ba0be77bc2bd8", null ],
      [ "operator()", "classKernel_1_1ConstructCircumcenter__3.html#a817ed817d48d0c9f0c6d74a5e561dfa4", null ],
      [ "operator()", "classKernel_1_1ConstructCircumcenter__3.html#afb6b8996402c6e76a3e2e12b32714d04", null ],
      [ "operator()", "classKernel_1_1ConstructCircumcenter__3.html#a53edc2bbacaad32c381ae02ad9d36cc6", null ]
    ] ],
    [ "Kernel::ConstructCrossProductVector_3", "classKernel_1_1ConstructCrossProductVector__3.html", [
      [ "operator()", "classKernel_1_1ConstructCrossProductVector__3.html#aeb28e50716ed8a0df74b3e316864c10a", null ]
    ] ],
    [ "Kernel::ConstructDifferenceOfVectors_2", "classKernel_1_1ConstructDifferenceOfVectors__2.html", [
      [ "operator()", "classKernel_1_1ConstructDifferenceOfVectors__2.html#a59bd94b1b9cdd88d7e787a101aed9348", null ]
    ] ],
    [ "Kernel::ConstructDifferenceOfVectors_3", "classKernel_1_1ConstructDifferenceOfVectors__3.html", [
      [ "operator()", "classKernel_1_1ConstructDifferenceOfVectors__3.html#ac2f5966fd330c0ae346f09251bb3417b", null ]
    ] ],
    [ "Kernel::ConstructDirection_2", "classKernel_1_1ConstructDirection__2.html", [
      [ "operator()", "classKernel_1_1ConstructDirection__2.html#a4c142e22428612b7cf252b074bcd47d0", null ],
      [ "operator()", "classKernel_1_1ConstructDirection__2.html#ad67f38e9e931f5d4c6fe69c23e795124", null ],
      [ "operator()", "classKernel_1_1ConstructDirection__2.html#af79edeaf28f7f04aaaaf5cfc586aee62", null ],
      [ "operator()", "classKernel_1_1ConstructDirection__2.html#a589bc4f13827580a8637ebd443981882", null ]
    ] ],
    [ "Kernel::ConstructDirection_3", "classKernel_1_1ConstructDirection__3.html", [
      [ "operator()", "classKernel_1_1ConstructDirection__3.html#a5a88a7aa5fa31c00ed8072aecf84694a", null ],
      [ "operator()", "classKernel_1_1ConstructDirection__3.html#a98cf72bda9c54b0a16f4fed4b62d44f4", null ],
      [ "operator()", "classKernel_1_1ConstructDirection__3.html#ad949c325beaa1bfcf2afa31107d4ec00", null ],
      [ "operator()", "classKernel_1_1ConstructDirection__3.html#a5d9fbeba7c61a2484836c29a56882664", null ]
    ] ],
    [ "Kernel::ConstructDividedVector_2", "classKernel_1_1ConstructDividedVector__2.html", [
      [ "operator()", "classKernel_1_1ConstructDividedVector__2.html#a96e056b1aa8adb4e492d8c0fc1ad11de", null ]
    ] ],
    [ "Kernel::ConstructDividedVector_3", "classKernel_1_1ConstructDividedVector__3.html", [
      [ "operator()", "classKernel_1_1ConstructDividedVector__3.html#aa9478e7e124aa84d832c3ab2e6d9b518", null ]
    ] ],
    [ "Kernel::ConstructEquidistantLine_3", "classKernel_1_1ConstructEquidistantLine__3.html", [
      [ "operator()", "classKernel_1_1ConstructEquidistantLine__3.html#aee3f7805b44437cc841ab09637759e51", null ]
    ] ],
    [ "Kernel::ConstructIsoCuboid_3", "classKernel_1_1ConstructIsoCuboid__3.html", [
      [ "operator()", "classKernel_1_1ConstructIsoCuboid__3.html#aa4a8f50bd462fb2f5527f5cc81072d35", null ],
      [ "operator()", "classKernel_1_1ConstructIsoCuboid__3.html#a5e899102c5dc46d9e5a261b36563be18", null ],
      [ "operator()", "classKernel_1_1ConstructIsoCuboid__3.html#af7f96b399b80313a4686cfae55e571ea", null ]
    ] ],
    [ "Kernel::ConstructIsoRectangle_2", "classKernel_1_1ConstructIsoRectangle__2.html", [
      [ "operator()", "classKernel_1_1ConstructIsoRectangle__2.html#a48b1b5493cdb0330839a5c310c04e1ac", null ],
      [ "operator()", "classKernel_1_1ConstructIsoRectangle__2.html#a1cc63ea16dbfa2c1329b01a4f790b08a", null ],
      [ "operator()", "classKernel_1_1ConstructIsoRectangle__2.html#abc683c0eacb4eb6e19bbebb52991a5a3", null ]
    ] ],
    [ "Kernel::ConstructLiftedPoint_3", "classKernel_1_1ConstructLiftedPoint__3.html", [
      [ "operator()", "classKernel_1_1ConstructLiftedPoint__3.html#aacace9b3e8e183a62655ee1ab720a560", null ]
    ] ],
    [ "Kernel::ConstructLine_2", "classKernel_1_1ConstructLine__2.html", [
      [ "operator()", "classKernel_1_1ConstructLine__2.html#a206847483cfc6beaf47e0a15c31989cf", null ],
      [ "operator()", "classKernel_1_1ConstructLine__2.html#a92ce8af635a22b94b230e65388688354", null ],
      [ "operator()", "classKernel_1_1ConstructLine__2.html#a558dcea7c7736d0b50026fa5c2db999e", null ],
      [ "operator()", "classKernel_1_1ConstructLine__2.html#a9ae410f38193ea7c1becc50d44fadc5f", null ],
      [ "operator()", "classKernel_1_1ConstructLine__2.html#a4c46e1a5f1054fffb8698f46986efbd4", null ]
    ] ],
    [ "Kernel::ConstructLine_3", "classKernel_1_1ConstructLine__3.html", [
      [ "operator()", "classKernel_1_1ConstructLine__3.html#af5494d4975c25623eb605feb3441d1e8", null ],
      [ "operator()", "classKernel_1_1ConstructLine__3.html#ad8d93520e3fad7ac6ffb17364fdbdf89", null ],
      [ "operator()", "classKernel_1_1ConstructLine__3.html#a9f7df79ec3b905d84b0eca7d4a3f2cb2", null ],
      [ "operator()", "classKernel_1_1ConstructLine__3.html#a6848e7f8dbb3a4725d001b059eec9791", null ],
      [ "operator()", "classKernel_1_1ConstructLine__3.html#a4b7973517cd62e2aeb820dceced83788", null ]
    ] ],
    [ "Kernel::ConstructMaxVertex_2", "classKernel_1_1ConstructMaxVertex__2.html", [
      [ "operator()", "classKernel_1_1ConstructMaxVertex__2.html#a533c15ca7691aaf3e35f20be44f0eff4", null ],
      [ "operator()", "classKernel_1_1ConstructMaxVertex__2.html#ad651ca736535400552126a2c0e8fa78b", null ]
    ] ],
    [ "Kernel::ConstructMaxVertex_3", "classKernel_1_1ConstructMaxVertex__3.html", [
      [ "operator()", "classKernel_1_1ConstructMaxVertex__3.html#a54a4ca28abd2f681fabf7ebc935be5d3", null ],
      [ "operator()", "classKernel_1_1ConstructMaxVertex__3.html#aad07c89a512235c7d18d57e132ec4576", null ]
    ] ],
    [ "Kernel::ConstructMidpoint_2", "classKernel_1_1ConstructMidpoint__2.html", [
      [ "operator()", "classKernel_1_1ConstructMidpoint__2.html#a025c5f736963909bd83c03288c568e8f", null ],
      [ "operator()", "classKernel_1_1ConstructMidpoint__2.html#a77f99fdb4b29ca44ce38aa5c27a1cb13", null ]
    ] ],
    [ "Kernel::ConstructMidpoint_3", "classKernel_1_1ConstructMidpoint__3.html", [
      [ "operator()", "classKernel_1_1ConstructMidpoint__3.html#a821d3d5185b73f344f9ed75a3b84931a", null ],
      [ "operator()", "classKernel_1_1ConstructMidpoint__3.html#af65b76a7203fd51803ec36796b4b5c76", null ]
    ] ],
    [ "Kernel::ConstructMinVertex_2", "classKernel_1_1ConstructMinVertex__2.html", [
      [ "operator()", "classKernel_1_1ConstructMinVertex__2.html#aa4d11309e39941eb69d36ed406b7c3a2", null ],
      [ "operator()", "classKernel_1_1ConstructMinVertex__2.html#a2a9e33081b5d1fdbc659365cc5302d9a", null ]
    ] ],
    [ "Kernel::ConstructMinVertex_3", "classKernel_1_1ConstructMinVertex__3.html", [
      [ "operator()", "classKernel_1_1ConstructMinVertex__3.html#a3ce667ea6cf94a335e0794066dbe500e", null ],
      [ "operator()", "classKernel_1_1ConstructMinVertex__3.html#ac2755f6d54f2296a4ce5e72a2925e03f", null ]
    ] ],
    [ "Kernel::ConstructNormal_3", "classKernel_1_1ConstructNormal__3.html", [
      [ "operator()", "classKernel_1_1ConstructNormal__3.html#aa6faef502c96607a05e216be57d89765", null ]
    ] ],
    [ "Kernel::ConstructObject_2", "classKernel_1_1ConstructObject__2.html", [
      [ "operator()", "classKernel_1_1ConstructObject__2.html#a4d0272916536d7684e1e2e0e6f67d2c4", null ]
    ] ],
    [ "Kernel::ConstructObject_3", "classKernel_1_1ConstructObject__3.html", [
      [ "operator()", "classKernel_1_1ConstructObject__3.html#a89a2ebc0b64c9fd9c6e518746c0f7cdd", null ]
    ] ],
    [ "Kernel::ConstructOppositeCircle_2", "classKernel_1_1ConstructOppositeCircle__2.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeCircle__2.html#afb9c9a79269b979bcb5074888e935348", null ]
    ] ],
    [ "Kernel::ConstructOppositeDirection_2", "classKernel_1_1ConstructOppositeDirection__2.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeDirection__2.html#a3cb71335a783919bd799a90cfc5edf00", null ]
    ] ],
    [ "Kernel::ConstructOppositeDirection_3", "classKernel_1_1ConstructOppositeDirection__3.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeDirection__3.html#a28db84afaa2973eea9b96c47d81cdc75", null ]
    ] ],
    [ "Kernel::ConstructOppositeLine_2", "classKernel_1_1ConstructOppositeLine__2.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeLine__2.html#afa7fccd71076639ed820943924469fe2", null ]
    ] ],
    [ "Kernel::ConstructOppositeLine_3", "classKernel_1_1ConstructOppositeLine__3.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeLine__3.html#aedf1bb02434c12d8950cecfb3b6c9264", null ]
    ] ],
    [ "Kernel::ConstructOppositePlane_3", "classKernel_1_1ConstructOppositePlane__3.html", [
      [ "operator()", "classKernel_1_1ConstructOppositePlane__3.html#accc3111ea49ef6c640121a7130265144", null ]
    ] ],
    [ "Kernel::ConstructOppositeRay_2", "classKernel_1_1ConstructOppositeRay__2.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeRay__2.html#a32c68330fb46e74bb00a32428496750a", null ]
    ] ],
    [ "Kernel::ConstructOppositeRay_3", "classKernel_1_1ConstructOppositeRay__3.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeRay__3.html#acc5f74ebd6310b1ddce937104688804d", null ]
    ] ],
    [ "Kernel::ConstructOppositeSegment_2", "classKernel_1_1ConstructOppositeSegment__2.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeSegment__2.html#a6aaa1d7ab23cbaca55e3afac1c83750b", null ]
    ] ],
    [ "Kernel::ConstructOppositeSegment_3", "classKernel_1_1ConstructOppositeSegment__3.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeSegment__3.html#a6c763bbf820600fb03ae587e40eba355", null ]
    ] ],
    [ "Kernel::ConstructOppositeSphere_3", "classKernel_1_1ConstructOppositeSphere__3.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeSphere__3.html#a4253cee52142c0e8311b732b8416e9e5", null ]
    ] ],
    [ "Kernel::ConstructOppositeTriangle_2", "classKernel_1_1ConstructOppositeTriangle__2.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeTriangle__2.html#ace15823f196309391d3390f4c4ce8583", null ]
    ] ],
    [ "Kernel::ConstructOppositeVector_2", "classKernel_1_1ConstructOppositeVector__2.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeVector__2.html#a71a113560d4818b96df6efac25263194", null ]
    ] ],
    [ "Kernel::ConstructOppositeVector_3", "classKernel_1_1ConstructOppositeVector__3.html", [
      [ "operator()", "classKernel_1_1ConstructOppositeVector__3.html#affb03a64aa856ed9c5000f6cc075da46", null ]
    ] ],
    [ "Kernel::ConstructOrthogonalVector_3", "classKernel_1_1ConstructOrthogonalVector__3.html", [
      [ "operator()", "classKernel_1_1ConstructOrthogonalVector__3.html#a073bc2e4e58e8ad7d931e186404c3d65", null ],
      [ "operator()", "classKernel_1_1ConstructOrthogonalVector__3.html#ac8af14dc9187868fb5d4a4c6762291bc", null ]
    ] ],
    [ "Kernel::ConstructPerpendicularDirection_2", "classKernel_1_1ConstructPerpendicularDirection__2.html", [
      [ "operator()", "classKernel_1_1ConstructPerpendicularDirection__2.html#aa3d183ef8ae1154ebe27b4d968f38050", null ]
    ] ],
    [ "Kernel::ConstructPerpendicularLine_2", "classKernel_1_1ConstructPerpendicularLine__2.html", [
      [ "operator()", "classKernel_1_1ConstructPerpendicularLine__2.html#af752e0d2e1074121e318fc9f60f1b0a3", null ]
    ] ],
    [ "Kernel::ConstructPerpendicularLine_3", "classKernel_1_1ConstructPerpendicularLine__3.html", [
      [ "operator()", "classKernel_1_1ConstructPerpendicularLine__3.html#ae32414841324bb829f524aac02304567", null ]
    ] ],
    [ "Kernel::ConstructPerpendicularPlane_3", "classKernel_1_1ConstructPerpendicularPlane__3.html", [
      [ "operator()", "classKernel_1_1ConstructPerpendicularPlane__3.html#a630660315f990d5243cf2680edbb6a98", null ]
    ] ],
    [ "Kernel::ConstructPerpendicularVector_2", "classKernel_1_1ConstructPerpendicularVector__2.html", [
      [ "operator()", "classKernel_1_1ConstructPerpendicularVector__2.html#a82f5127dd9cec6729c52f34022609411", null ]
    ] ],
    [ "Kernel::ConstructPlane_3", "classKernel_1_1ConstructPlane__3.html", [
      [ "operator()", "classKernel_1_1ConstructPlane__3.html#a28d06c5c3c50318f0651c5bd5de26cd8", null ],
      [ "operator()", "classKernel_1_1ConstructPlane__3.html#ac782f5f889f0e5946a5fde063c94ee4b", null ],
      [ "operator()", "classKernel_1_1ConstructPlane__3.html#a2c7931b111144112cad55293c35532d3", null ],
      [ "operator()", "classKernel_1_1ConstructPlane__3.html#ad0fa17bffeeeb964f3781c297492c98b", null ],
      [ "operator()", "classKernel_1_1ConstructPlane__3.html#a26b248332d683a5b440f0c66e556ddca", null ],
      [ "operator()", "classKernel_1_1ConstructPlane__3.html#a4b81de97d6b399144f0d61b3a2a8e916", null ],
      [ "operator()", "classKernel_1_1ConstructPlane__3.html#af4eff4bb84176b6c158b0aca80ee3ccd", null ],
      [ "operator()", "classKernel_1_1ConstructPlane__3.html#a8c541c337f4548a7cb1c79b1a97febee", null ]
    ] ],
    [ "Kernel::ConstructPointOn_2", "classKernel_1_1ConstructPointOn__2.html", [
      [ "operator()", "classKernel_1_1ConstructPointOn__2.html#acbf8bfba665b4118612aef02f8ecf678", null ],
      [ "operator()", "classKernel_1_1ConstructPointOn__2.html#af8e9d909cb9f49c0bc7e1e272acfb0c1", null ],
      [ "operator()", "classKernel_1_1ConstructPointOn__2.html#aeadc59c27c06a8d660045ca41b8de169", null ]
    ] ],
    [ "Kernel::ConstructPointOn_3", "classKernel_1_1ConstructPointOn__3.html", [
      [ "operator()", "classKernel_1_1ConstructPointOn__3.html#aa18da4ad00632312e6eb56d5d9a40830", null ],
      [ "operator()", "classKernel_1_1ConstructPointOn__3.html#a541c60c8867d972e82fa6b68649fb4d8", null ],
      [ "operator()", "classKernel_1_1ConstructPointOn__3.html#a096b835df3fafc05b3ecc42bab725bed", null ],
      [ "operator()", "classKernel_1_1ConstructPointOn__3.html#abfb9500422554965bdd3d5b9d0f544d3", null ],
      [ "operator()", "classKernel_1_1ConstructPointOn__3.html#a4bb308802938d7e60827cd42c359c4a3", null ]
    ] ],
    [ "Kernel::ConstructPoint_2", "classKernel_1_1ConstructPoint__2.html", [
      [ "operator()", "classKernel_1_1ConstructPoint__2.html#a7c7ea25d064afd979fba0a63ba2066b1", null ],
      [ "operator()", "classKernel_1_1ConstructPoint__2.html#a01fa962280ec1c2f9ebd4556a8c537ac", null ],
      [ "operator()", "classKernel_1_1ConstructPoint__2.html#adc5e1c868cc832e27e9de797c33a6b68", null ]
    ] ],
    [ "Kernel::ConstructPoint_3", "classKernel_1_1ConstructPoint__3.html", [
      [ "operator()", "classKernel_1_1ConstructPoint__3.html#a37649d35c2e6ce0fc9db1197e0c44801", null ],
      [ "operator()", "classKernel_1_1ConstructPoint__3.html#a8a6d2e5f5d546e269293f96d7e74813e", null ],
      [ "operator()", "classKernel_1_1ConstructPoint__3.html#abc81173f20fe694f465b080e0281d0d7", null ]
    ] ],
    [ "Kernel::ConstructProjectedPoint_2", "classKernel_1_1ConstructProjectedPoint__2.html", [
      [ "operator()", "classKernel_1_1ConstructProjectedPoint__2.html#a61f7570c737e48fe65bdf23c2d1073df", null ],
      [ "operator()", "classKernel_1_1ConstructProjectedPoint__2.html#a369a679d8194ef59bc1eb947f1d307d8", null ],
      [ "operator()", "classKernel_1_1ConstructProjectedPoint__2.html#ab1cb99c0be3a4067c2e1c6b6a9e2092e", null ]
    ] ],
    [ "Kernel::ConstructProjectedPoint_3", "classKernel_1_1ConstructProjectedPoint__3.html", [
      [ "operator()", "classKernel_1_1ConstructProjectedPoint__3.html#ab0bcfb87b684eb7c163f986806865004", null ],
      [ "operator()", "classKernel_1_1ConstructProjectedPoint__3.html#a90efad657269d9a548d208b2ad43be53", null ],
      [ "operator()", "classKernel_1_1ConstructProjectedPoint__3.html#add919ed5851b36c2a18abe3c0382c1e4", null ],
      [ "operator()", "classKernel_1_1ConstructProjectedPoint__3.html#a1d3dace7a282f27f76749fb44dfac63f", null ],
      [ "operator()", "classKernel_1_1ConstructProjectedPoint__3.html#aa6a69663d382eda1545fbe09334fdf3c", null ]
    ] ],
    [ "Kernel::ConstructProjectedXYPoint_2", "classKernel_1_1ConstructProjectedXYPoint__2.html", [
      [ "operator()", "classKernel_1_1ConstructProjectedXYPoint__2.html#a25c4cc1a82ba54efece8d250e07cdbd7", null ]
    ] ],
    [ "Kernel::ConstructRadicalAxis_2", "classKernel_1_1ConstructRadicalAxis__2.html", [
      [ "operator()", "classKernel_1_1ConstructRadicalAxis__2.html#a54b7692d0adbfa41c0f15a257e67d907", null ]
    ] ],
    [ "Kernel::ConstructRadicalLine_2", "classKernel_1_1ConstructRadicalLine__2.html", [
      [ "operator()", "classKernel_1_1ConstructRadicalLine__2.html#aeca48303c1e44142c2e003b2b3b02fbc", null ]
    ] ],
    [ "Kernel::ConstructRadicalPlane_3", "classKernel_1_1ConstructRadicalPlane__3.html", [
      [ "operator()", "classKernel_1_1ConstructRadicalPlane__3.html#a2738404afa6916d8168cc1cfd9bc6f8b", null ]
    ] ],
    [ "Kernel::ConstructRay_2", "classKernel_1_1ConstructRay__2.html", [
      [ "operator()", "classKernel_1_1ConstructRay__2.html#a1ca2885852180be501c23b54f38c6eff", null ],
      [ "operator()", "classKernel_1_1ConstructRay__2.html#ac96021d7cbdabda05f734ec7fb6cf96b", null ],
      [ "operator()", "classKernel_1_1ConstructRay__2.html#aaf17643370636830ca5ac402ee9270b4", null ],
      [ "operator()", "classKernel_1_1ConstructRay__2.html#af36248b39f3b3a997b797e0aa2af82fa", null ]
    ] ],
    [ "Kernel::ConstructRay_3", "classKernel_1_1ConstructRay__3.html", [
      [ "operator()", "classKernel_1_1ConstructRay__3.html#aeb16d1dcdab03fe8aabdbe8108c44d32", null ],
      [ "operator()", "classKernel_1_1ConstructRay__3.html#a9041513992451e945d62c9e44be86112", null ],
      [ "operator()", "classKernel_1_1ConstructRay__3.html#a25471f1d37e126060e250376580c3041", null ],
      [ "operator()", "classKernel_1_1ConstructRay__3.html#ae3eb5d2d7d88616daf256f2bcc5b07d7", null ]
    ] ],
    [ "Kernel::ConstructScaledVector_2", "classKernel_1_1ConstructScaledVector__2.html", [
      [ "operator()", "classKernel_1_1ConstructScaledVector__2.html#a467c9cad1f78863521e53e1d70906d03", null ],
      [ "operator()", "classKernel_1_1ConstructScaledVector__2.html#ad6ef649ed7c6615c108a34db52d1bc59", null ]
    ] ],
    [ "Kernel::ConstructScaledVector_3", "classKernel_1_1ConstructScaledVector__3.html", [
      [ "operator()", "classKernel_1_1ConstructScaledVector__3.html#a477478ac7b21aebfc1bcec35d3f87f42", null ],
      [ "operator()", "classKernel_1_1ConstructScaledVector__3.html#a95e8e15f2b8da1d2748d9ee7de8768f3", null ]
    ] ],
    [ "Kernel::ConstructSecondPoint_2", "classKernel_1_1ConstructSecondPoint__2.html", [
      [ "operator()", "classKernel_1_1ConstructSecondPoint__2.html#aff4f2f3db860164ec3ae81a18e857cc3", null ]
    ] ],
    [ "Kernel::ConstructSecondPoint_3", "classKernel_1_1ConstructSecondPoint__3.html", [
      [ "operator()", "classKernel_1_1ConstructSecondPoint__3.html#aceb7eaae9fd91451f060bf1062feff06", null ]
    ] ],
    [ "Kernel::ConstructSegment_2", "classKernel_1_1ConstructSegment__2.html", [
      [ "operator()", "classKernel_1_1ConstructSegment__2.html#a8824d4440c674b5fe5ee89e0e4254a58", null ]
    ] ],
    [ "Kernel::ConstructSegment_3", "classKernel_1_1ConstructSegment__3.html", [
      [ "operator()", "classKernel_1_1ConstructSegment__3.html#af128171f91a5026b265d4c8f761556f7", null ]
    ] ],
    [ "Kernel::ConstructSource_2", "classKernel_1_1ConstructSource__2.html", [
      [ "operator()", "classKernel_1_1ConstructSource__2.html#a72bbe38735664bf7d245accf1e570a68", null ],
      [ "operator()", "classKernel_1_1ConstructSource__2.html#a36ca1189925540584ef81b924dcb1562", null ]
    ] ],
    [ "Kernel::ConstructSource_3", "classKernel_1_1ConstructSource__3.html", [
      [ "operator()", "classKernel_1_1ConstructSource__3.html#afa8c281ec7ba08d9f925259a308010bc", null ],
      [ "operator()", "classKernel_1_1ConstructSource__3.html#a3c79923d082d9661cfc3cb1b650b865f", null ]
    ] ],
    [ "Kernel::ConstructSphere_3", "classKernel_1_1ConstructSphere__3.html", [
      [ "operator()", "classKernel_1_1ConstructSphere__3.html#ab050f9a640a537761a995e20ee9849f3", null ],
      [ "operator()", "classKernel_1_1ConstructSphere__3.html#a7dab70c9b83666ddc359c8cc03ecfb82", null ],
      [ "operator()", "classKernel_1_1ConstructSphere__3.html#a578bebba763d1fd3abc3899ccbaca855", null ],
      [ "operator()", "classKernel_1_1ConstructSphere__3.html#a15e5e6190c9b62280240052425c9930e", null ],
      [ "operator()", "classKernel_1_1ConstructSphere__3.html#a3931f2464ad5e3c9f7694930356c27d7", null ],
      [ "operator()", "classKernel_1_1ConstructSphere__3.html#adab884a8708ad7e6368bcdcc835170a6", null ]
    ] ],
    [ "Kernel::ConstructSumOfVectors_2", "classKernel_1_1ConstructSumOfVectors__2.html", [
      [ "operator()", "classKernel_1_1ConstructSumOfVectors__2.html#a24090bc99798bed77f625dd451fa373e", null ]
    ] ],
    [ "Kernel::ConstructSumOfVectors_3", "classKernel_1_1ConstructSumOfVectors__3.html", [
      [ "operator()", "classKernel_1_1ConstructSumOfVectors__3.html#a6c585b8a0ed78b088d7b8b3ddb5dffa6", null ]
    ] ],
    [ "Kernel::ConstructSupportingPlane_3", "classKernel_1_1ConstructSupportingPlane__3.html", [
      [ "operator()", "classKernel_1_1ConstructSupportingPlane__3.html#a3006b003d89ba114f1f815c941b1e5e0", null ]
    ] ],
    [ "Kernel::ConstructTarget_2", "classKernel_1_1ConstructTarget__2.html", [
      [ "operator()", "classKernel_1_1ConstructTarget__2.html#a5ff17293b314b9088a644032791f56c2", null ]
    ] ],
    [ "Kernel::ConstructTarget_3", "classKernel_1_1ConstructTarget__3.html", [
      [ "operator()", "classKernel_1_1ConstructTarget__3.html#a22f86aacb854869a974f71e8b817c192", null ]
    ] ],
    [ "Kernel::ConstructTetrahedron_3", "classKernel_1_1ConstructTetrahedron__3.html", [
      [ "operator()", "classKernel_1_1ConstructTetrahedron__3.html#a050198f413127758e8a8a7133b7237bd", null ]
    ] ],
    [ "Kernel::ConstructTranslatedPoint_2", "classKernel_1_1ConstructTranslatedPoint__2.html", [
      [ "operator()", "classKernel_1_1ConstructTranslatedPoint__2.html#aa5d1e1b3089e49a32d8cf1d60c72b935", null ],
      [ "operator()", "classKernel_1_1ConstructTranslatedPoint__2.html#ab8ff379bf836bde7c64b8506e181eed6", null ]
    ] ],
    [ "Kernel::ConstructTranslatedPoint_3", "classKernel_1_1ConstructTranslatedPoint__3.html", [
      [ "operator()", "classKernel_1_1ConstructTranslatedPoint__3.html#a7e61a9cd5368452af22a4114c82db98e", null ],
      [ "operator()", "classKernel_1_1ConstructTranslatedPoint__3.html#a6912d03683fd4e5dbedbca072b460b99", null ]
    ] ],
    [ "Kernel::ConstructTriangle_2", "classKernel_1_1ConstructTriangle__2.html", [
      [ "operator()", "classKernel_1_1ConstructTriangle__2.html#a3588896ac363c7d8abdb9c983a2f7b1d", null ]
    ] ],
    [ "Kernel::ConstructTriangle_3", "classKernel_1_1ConstructTriangle__3.html", [
      [ "operator()", "classKernel_1_1ConstructTriangle__3.html#a6f11e516d81a309de2a4889a3cca11c2", null ]
    ] ],
    [ "Kernel::ConstructUnitNormal_3", "classKernel_1_1ConstructUnitNormal__3.html", [
      [ "operator()", "classKernel_1_1ConstructUnitNormal__3.html#af52f0200f5a8f15da4ff1729849f4cef", null ]
    ] ],
    [ "Kernel::ConstructVector_2", "classKernel_1_1ConstructVector__2.html", [
      [ "operator()", "classKernel_1_1ConstructVector__2.html#afbfcc927aabeb1f71231324efee7c5a5", null ],
      [ "operator()", "classKernel_1_1ConstructVector__2.html#a6c8d4c1b6a56392c34a10868d2482fe8", null ],
      [ "operator()", "classKernel_1_1ConstructVector__2.html#ab4fc4a886e18906b685946f5ccf469f9", null ],
      [ "operator()", "classKernel_1_1ConstructVector__2.html#a5a7d56e589df4d2487a77c8d0602e3e1", null ],
      [ "operator()", "classKernel_1_1ConstructVector__2.html#a56811757789d71a566b13ee86a7a90fc", null ],
      [ "operator()", "classKernel_1_1ConstructVector__2.html#a87acd718350d56f0347427ce1bf702a7", null ],
      [ "operator()", "classKernel_1_1ConstructVector__2.html#ad25e50a78605652e062f0774dd573646", null ]
    ] ],
    [ "Kernel::ConstructVector_3", "classKernel_1_1ConstructVector__3.html", [
      [ "operator()", "classKernel_1_1ConstructVector__3.html#a0fc7fef29c56c910ac5026ad2c88e054", null ],
      [ "operator()", "classKernel_1_1ConstructVector__3.html#a165a6f439792b1dd1b669a314a446569", null ],
      [ "operator()", "classKernel_1_1ConstructVector__3.html#a519e87b215c9a9d90604c83c73d5d73e", null ],
      [ "operator()", "classKernel_1_1ConstructVector__3.html#a3cb9482318a4f0baa5ca10eb609dd77e", null ],
      [ "operator()", "classKernel_1_1ConstructVector__3.html#ab14e10bb07bdb4aeb089b109f06cd807", null ],
      [ "operator()", "classKernel_1_1ConstructVector__3.html#a4dac6e18d033d738c65ee9e77075bf6e", null ],
      [ "operator()", "classKernel_1_1ConstructVector__3.html#a2a9cf2319d1127fa3b4a476b0d39bcdf", null ]
    ] ],
    [ "Kernel::ConstructVertex_2", "classKernel_1_1ConstructVertex__2.html", [
      [ "operator()", "classKernel_1_1ConstructVertex__2.html#a73fa0e80b1e9f32f4376efc3234ff799", null ],
      [ "operator()", "classKernel_1_1ConstructVertex__2.html#a2cb3a962b5e11838f5dcda1e98eed9c3", null ],
      [ "operator()", "classKernel_1_1ConstructVertex__2.html#a3142969c136f9a5de491a9505de7e9c5", null ]
    ] ],
    [ "Kernel::ConstructVertex_3", "classKernel_1_1ConstructVertex__3.html", [
      [ "operator()", "classKernel_1_1ConstructVertex__3.html#a8995ccf20716cd985ba1c8087bb77080", null ],
      [ "operator()", "classKernel_1_1ConstructVertex__3.html#abb173c9c3adb4cba686a688e1a1d2d4c", null ],
      [ "operator()", "classKernel_1_1ConstructVertex__3.html#a0352b1c3962712caedaa6fab0931a000", null ],
      [ "operator()", "classKernel_1_1ConstructVertex__3.html#abb14ec0125f1d95c031bf61f7ba1d66a", null ]
    ] ],
    [ "Kernel::ConstructWeightedCircumcenter_2", "classKernel_1_1ConstructWeightedCircumcenter__2.html", [
      [ "operator()", "classKernel_1_1ConstructWeightedCircumcenter__2.html#a4b3c59554c3738996fb9729b23238004", null ]
    ] ],
    [ "Kernel::ConstructWeightedCircumcenter_3", "classKernel_1_1ConstructWeightedCircumcenter__3.html", [
      [ "operator()", "classKernel_1_1ConstructWeightedCircumcenter__3.html#aeb5649b36e888fe8722e2445fd46a6d2", null ],
      [ "operator()", "classKernel_1_1ConstructWeightedCircumcenter__3.html#a4368a5082df48df11114ced622b2e762", null ],
      [ "operator()", "classKernel_1_1ConstructWeightedCircumcenter__3.html#a20095ced7a81c9cf3ebbf1518ee82b9c", null ]
    ] ],
    [ "Kernel::ConstructWeightedPoint_2", "classKernel_1_1ConstructWeightedPoint__2.html", [
      [ "operator()", "classKernel_1_1ConstructWeightedPoint__2.html#a077a2fa6f85c0572348798c1ff1e7753", null ],
      [ "operator()", "classKernel_1_1ConstructWeightedPoint__2.html#a07e896e306398ae27fcff668dac08334", null ],
      [ "operator()", "classKernel_1_1ConstructWeightedPoint__2.html#a04ef384df4ee7b53ff855e2dd66f06ca", null ]
    ] ],
    [ "Kernel::ConstructWeightedPoint_3", "classKernel_1_1ConstructWeightedPoint__3.html", [
      [ "operator()", "classKernel_1_1ConstructWeightedPoint__3.html#a994ab0c1285e32b33cf1df67c3a8b481", null ],
      [ "operator()", "classKernel_1_1ConstructWeightedPoint__3.html#ae5538fffaa44b1b0c0f0f269b5a0d2a1", null ],
      [ "operator()", "classKernel_1_1ConstructWeightedPoint__3.html#a0af17fcbfa353e0fdd0bec18b60951a5", null ]
    ] ],
    [ "Kernel::CoplanarOrientation_3", "classKernel_1_1CoplanarOrientation__3.html", [
      [ "operator()", "classKernel_1_1CoplanarOrientation__3.html#aac655e1b87550abef70ad395c7b55d16", null ],
      [ "operator()", "classKernel_1_1CoplanarOrientation__3.html#aa24994f282b13f45a7f4019e481f67b4", null ]
    ] ],
    [ "Kernel::CoplanarSideOfBoundedCircle_3", "classKernel_1_1CoplanarSideOfBoundedCircle__3.html", [
      [ "operator()", "classKernel_1_1CoplanarSideOfBoundedCircle__3.html#a9a64fe3d40d2f9c740c1e06f619177b8", null ]
    ] ],
    [ "Kernel::Coplanar_3", "classKernel_1_1Coplanar__3.html", [
      [ "operator()", "classKernel_1_1Coplanar__3.html#a8acb2361196b83adf5bcdb13bca1f3b5", null ]
    ] ],
    [ "Kernel::CounterclockwiseInBetween_2", "classKernel_1_1CounterclockwiseInBetween__2.html", [
      [ "operator()", "classKernel_1_1CounterclockwiseInBetween__2.html#a71a6c7d9a36bc53bcfba51d2b5791796", null ]
    ] ],
    [ "Kernel::DoIntersect_2", "classKernel_1_1DoIntersect__2.html", [
      [ "operator()", "classKernel_1_1DoIntersect__2.html#a730714190a4f303cd74b9e4929df236a", null ]
    ] ],
    [ "Kernel::DoIntersect_3", "classKernel_1_1DoIntersect__3.html", [
      [ "operator()", "classKernel_1_1DoIntersect__3.html#a848786a76b41680f70fd9953d6abc73b", null ]
    ] ],
    [ "Kernel::EqualXY_3", "classKernel_1_1EqualXY__3.html", [
      [ "operator()", "classKernel_1_1EqualXY__3.html#a0fde070bfe40e7af24b59fb7ff25844c", null ]
    ] ],
    [ "Kernel::EqualX_2", "classKernel_1_1EqualX__2.html", [
      [ "operator()", "classKernel_1_1EqualX__2.html#acb19c159c61369e789cdd778cbe20558", null ]
    ] ],
    [ "Kernel::EqualX_3", "classKernel_1_1EqualX__3.html", [
      [ "operator()", "classKernel_1_1EqualX__3.html#a1ed4b8ec978a19a7d742893d792c0666", null ]
    ] ],
    [ "Kernel::EqualY_2", "classKernel_1_1EqualY__2.html", [
      [ "operator()", "classKernel_1_1EqualY__2.html#a9e80797c73503b5eb582f6462e87470e", null ]
    ] ],
    [ "Kernel::EqualY_3", "classKernel_1_1EqualY__3.html", [
      [ "operator()", "classKernel_1_1EqualY__3.html#ab4c3c39322273cb5f588f840c9b768c3", null ]
    ] ],
    [ "Kernel::EqualZ_3", "classKernel_1_1EqualZ__3.html", [
      [ "operator()", "classKernel_1_1EqualZ__3.html#a3d2bbc4a5073d7945551070eaad9a3f9", null ]
    ] ],
    [ "Kernel::Equal_2", "classKernel_1_1Equal__2.html", [
      [ "operator()", "classKernel_1_1Equal__2.html#a4031555fb327fbc38a919782644a0230", null ],
      [ "operator()", "classKernel_1_1Equal__2.html#a4182955999ada0612389e4c261945130", null ],
      [ "operator()", "classKernel_1_1Equal__2.html#afd9c6b2c1da3ef5742dc03894a68ff58", null ],
      [ "operator()", "classKernel_1_1Equal__2.html#a1e95d9b277d246dd3beaa3186164bd95", null ],
      [ "operator()", "classKernel_1_1Equal__2.html#a2d8fd0770587c2b3a38738968d39900d", null ],
      [ "operator()", "classKernel_1_1Equal__2.html#adeb7bf5778b72df36e8b8efb9a3c16a9", null ],
      [ "operator()", "classKernel_1_1Equal__2.html#ab480b7a287645a11c209adbdcf0ca31a", null ],
      [ "operator()", "classKernel_1_1Equal__2.html#a04fcc68d3eca46e61a78b04962bbfe14", null ],
      [ "operator()", "classKernel_1_1Equal__2.html#ab3f1fcdd4db8a24272f2554c9d11bb87", null ]
    ] ],
    [ "Kernel::Equal_3", "classKernel_1_1Equal__3.html", [
      [ "operator()", "classKernel_1_1Equal__3.html#a1748db160ba97d513319b539677d4b81", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a2d13a9e2babf9d82db3aeef3c3e0d9f1", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a4f19cf5f905179f0af11a87f997f0fcd", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a39fe241fc6ba392575b26dbc41347fa7", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a8ed86933b6fdb296329dacff56b22bd5", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#aafbf1f4bd80c09ba88e0763e2df72fe9", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a674eba752bf2db04e2c3d0d5d6b34e48", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#af376958033b636928fb920a15ba5975f", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a3744b1d15cf3768f9b550f47cddd7bfb", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a740a5fd5f47aea2b0a7613c8fca16c2e", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a566bcceff1a016f6095ebfab46aa76b8", null ],
      [ "operator()", "classKernel_1_1Equal__3.html#a27dca9791b2203867b041d134013264a", null ]
    ] ],
    [ "Kernel::HasOnBoundary_2", "classKernel_1_1HasOnBoundary__2.html", [
      [ "operator()", "classKernel_1_1HasOnBoundary__2.html#a6e55e99e3bd61acdb3541d0026f29b2d", null ],
      [ "operator()", "classKernel_1_1HasOnBoundary__2.html#ad598f0aa9bd5a08637e5fccc7c00ff95", null ],
      [ "operator()", "classKernel_1_1HasOnBoundary__2.html#a290c44969eef34b202b9125bf7337c80", null ]
    ] ],
    [ "Kernel::HasOnBoundary_3", "classKernel_1_1HasOnBoundary__3.html", [
      [ "operator()", "classKernel_1_1HasOnBoundary__3.html#a02ddbb9a3895c18316d3d367e9883ceb", null ],
      [ "operator()", "classKernel_1_1HasOnBoundary__3.html#a22b74d530951bbd3f561059ec4629b11", null ],
      [ "operator()", "classKernel_1_1HasOnBoundary__3.html#ace03f72d51be814b0c0cb672374b1ddb", null ]
    ] ],
    [ "Kernel::HasOnBoundedSide_2", "classKernel_1_1HasOnBoundedSide__2.html", [
      [ "operator()", "classKernel_1_1HasOnBoundedSide__2.html#a8b30f3ecd76a9bfe5ea37614e2a2f505", null ],
      [ "operator()", "classKernel_1_1HasOnBoundedSide__2.html#ab478e8289ca03b229d091ea17450279d", null ],
      [ "operator()", "classKernel_1_1HasOnBoundedSide__2.html#aed0f3d341534cf2dbf5ed228618170ab", null ]
    ] ],
    [ "Kernel::HasOnBoundedSide_3", "classKernel_1_1HasOnBoundedSide__3.html", [
      [ "operator()", "classKernel_1_1HasOnBoundedSide__3.html#af95a3c7c651b4fe3ecb0ec08f4d07d1c", null ],
      [ "operator()", "classKernel_1_1HasOnBoundedSide__3.html#a140f0de6d600f58133edbbd2c054aea4", null ],
      [ "operator()", "classKernel_1_1HasOnBoundedSide__3.html#a0bfac78507f1fe1c9f946408f7f1b0b9", null ],
      [ "operator()", "classKernel_1_1HasOnBoundedSide__3.html#a879efe7f55b4ae8f2bd0d1acca42b6e4", null ],
      [ "operator()", "classKernel_1_1HasOnBoundedSide__3.html#a675b12efd4ff8c3d83997e59db3ff0f6", null ]
    ] ],
    [ "Kernel::HasOnNegativeSide_2", "classKernel_1_1HasOnNegativeSide__2.html", [
      [ "operator()", "classKernel_1_1HasOnNegativeSide__2.html#a427070bc873950567d37dbff39a07108", null ],
      [ "operator()", "classKernel_1_1HasOnNegativeSide__2.html#a5ac5d40b076ca97d8c8130720e46dba4", null ],
      [ "operator()", "classKernel_1_1HasOnNegativeSide__2.html#a5e31397006d0b449cecb19d3fc4123ce", null ]
    ] ],
    [ "Kernel::HasOnNegativeSide_3", "classKernel_1_1HasOnNegativeSide__3.html", [
      [ "operator()", "classKernel_1_1HasOnNegativeSide__3.html#a02528cbd1bb38f7b49a2172b49c2c0d3", null ],
      [ "operator()", "classKernel_1_1HasOnNegativeSide__3.html#aac94612d3ef9d201c7285a10a9626b52", null ],
      [ "operator()", "classKernel_1_1HasOnNegativeSide__3.html#ac8a90db7a1b8cdc975bd2b830456f61d", null ]
    ] ],
    [ "Kernel::HasOnPositiveSide_2", "classKernel_1_1HasOnPositiveSide__2.html", [
      [ "operator()", "classKernel_1_1HasOnPositiveSide__2.html#ae7b1568f2f227c33335b079e0d5f820a", null ],
      [ "operator()", "classKernel_1_1HasOnPositiveSide__2.html#a8d76b025b69daccc9246e284092656b7", null ],
      [ "operator()", "classKernel_1_1HasOnPositiveSide__2.html#a29af6bc4b8d15ba66fac1509956b24ba", null ]
    ] ],
    [ "Kernel::HasOnPositiveSide_3", "classKernel_1_1HasOnPositiveSide__3.html", [
      [ "operator()", "classKernel_1_1HasOnPositiveSide__3.html#ab09e67c2ffe773d97330d1501f88c566", null ],
      [ "operator()", "classKernel_1_1HasOnPositiveSide__3.html#ad725bf891b688494594068f82db2324f", null ],
      [ "operator()", "classKernel_1_1HasOnPositiveSide__3.html#a7fb24ba79bff5f3d6a54f415ba63cdf2", null ]
    ] ],
    [ "Kernel::HasOnUnboundedSide_2", "classKernel_1_1HasOnUnboundedSide__2.html", [
      [ "operator()", "classKernel_1_1HasOnUnboundedSide__2.html#a259db50f24c56ea7f346ffce550f3d21", null ],
      [ "operator()", "classKernel_1_1HasOnUnboundedSide__2.html#a3108f91c2698eaf62e85b84fef0c6731", null ],
      [ "operator()", "classKernel_1_1HasOnUnboundedSide__2.html#a8ca70b14d279c41a5c1d314b1de22b59", null ]
    ] ],
    [ "Kernel::HasOnUnboundedSide_3", "classKernel_1_1HasOnUnboundedSide__3.html", [
      [ "operator()", "classKernel_1_1HasOnUnboundedSide__3.html#a9cf16ab055032c75bd715d10b76b10a8", null ],
      [ "operator()", "classKernel_1_1HasOnUnboundedSide__3.html#a4b2c27a0593727a253a416adadc37d29", null ],
      [ "operator()", "classKernel_1_1HasOnUnboundedSide__3.html#a3778b1b8f39cad82d92a5bcbd49a9086", null ],
      [ "operator()", "classKernel_1_1HasOnUnboundedSide__3.html#a690242150d4b9397e441273361574774", null ]
    ] ],
    [ "Kernel::HasOn_2", "classKernel_1_1HasOn__2.html", [
      [ "operator()", "classKernel_1_1HasOn__2.html#ab938ddb802eb51b69cb1f819aef30f6e", null ],
      [ "operator()", "classKernel_1_1HasOn__2.html#a89e1963bd17ae3b2d80fc87d67ee5257", null ],
      [ "operator()", "classKernel_1_1HasOn__2.html#ad5837ab009b676cdf3bb4c236560a656", null ]
    ] ],
    [ "Kernel::HasOn_3", "classKernel_1_1HasOn__3.html", [
      [ "operator()", "classKernel_1_1HasOn__3.html#a3e045b4b4e9d7d7509285c047793b7f2", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#ae4bb7458bbc06eae0b66c3f759383641", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#a151e1848d8dd2bb056872b6d7ef6ecdc", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#a7342749b4d33bd15d4dd309a26f7b8a7", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#a81614d85aa609ec6a282cf0bbebb48ae", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#a2fd2e8f39e040d6103262654d97ef1ff", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#aaa9462bbfe01f162d21359ab744e910d", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#aedbeef9a5bf64bc0d0ec656df98067e3", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#afc33d5b0386c2b72d365ddc9b4297fea", null ],
      [ "operator()", "classKernel_1_1HasOn__3.html#ace46b50f7294499722f854af7ff2de6a", null ]
    ] ],
    [ "Kernel::Intersect_2", "classKernel_1_1Intersect__2.html", [
      [ "operator()", "classKernel_1_1Intersect__2.html#a5635fa0675ce91e4b81d7a28f78f3a5f", null ]
    ] ],
    [ "Kernel::Intersect_3", "classKernel_1_1Intersect__3.html", [
      [ "operator()", "classKernel_1_1Intersect__3.html#af51ef23aaca058e4b62a26852ca74fae", null ]
    ] ],
    [ "Kernel::IsDegenerate_2", "classKernel_1_1IsDegenerate__2.html", [
      [ "operator()", "classKernel_1_1IsDegenerate__2.html#afe331f9c9cfc6df6343f17baf878bfa2", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__2.html#a38e979d82f2deeb51af6b43caad803a2", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__2.html#a5b57b2f23cafcc43054fa95a74f774a0", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__2.html#a4844e751352243f8f60f074beee98c18", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__2.html#abcafeea493f69749b1ad832ff3881a02", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__2.html#a30c77ef39290e14674faf1c8e674c8ab", null ]
    ] ],
    [ "Kernel::IsDegenerate_3", "classKernel_1_1IsDegenerate__3.html", [
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#a66b8341f36ead262054f1b2780b2f854", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#a54569687958fd4914c48fa5d85d804a3", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#a29c56292e18d3dd07e79f2fbde373286", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#a3df365dab543fc779c23aa031b3aa741", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#af8d9fbb96d139375f78f3b0d8989b878", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#a5dc48e597385a16e47e6b49924332c5c", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#af601554273f3da019d1a85019cbf73ab", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#aacdefe20996a2956bf20dccecacbead0", null ],
      [ "operator()", "classKernel_1_1IsDegenerate__3.html#a03e984dc8e24518d2805feee41573f68", null ]
    ] ],
    [ "Kernel::IsHorizontal_2", "classKernel_1_1IsHorizontal__2.html", [
      [ "operator()", "classKernel_1_1IsHorizontal__2.html#afcf4d0026e60cb905f5f4922b03fb439", null ],
      [ "operator()", "classKernel_1_1IsHorizontal__2.html#a04d52b850e83cb317ac87652aecd2436", null ],
      [ "operator()", "classKernel_1_1IsHorizontal__2.html#aa0655a036f15f5364f8188041c34bc0f", null ]
    ] ],
    [ "Kernel::IsVertical_2", "classKernel_1_1IsVertical__2.html", [
      [ "operator()", "classKernel_1_1IsVertical__2.html#ae1eaa424f2f390fce3fb7a75693f5fa1", null ],
      [ "operator()", "classKernel_1_1IsVertical__2.html#aa254864d665abd786b2f6b2180450d30", null ],
      [ "operator()", "classKernel_1_1IsVertical__2.html#a119756079fc01062bae06f204e461659", null ]
    ] ],
    [ "Kernel::LeftTurn_2", "classKernel_1_1LeftTurn__2.html", [
      [ "operator()", "classKernel_1_1LeftTurn__2.html#a82e5bcc667ce31f9e16d35a07fa5d3b7", null ]
    ] ],
    [ "Kernel::LessDistanceToPoint_2", "classKernel_1_1LessDistanceToPoint__2.html", [
      [ "operator()", "classKernel_1_1LessDistanceToPoint__2.html#a31ffc4f89cc2fa4e5ab5bb69f3fa4c87", null ]
    ] ],
    [ "Kernel::LessDistanceToPoint_3", "classKernel_1_1LessDistanceToPoint__3.html", [
      [ "operator()", "classKernel_1_1LessDistanceToPoint__3.html#a6e43d7e079bb7fc4f9fc2611d124c3e9", null ]
    ] ],
    [ "Kernel::LessRotateCCW_2", "classKernel_1_1LessRotateCCW__2.html", [
      [ "operator()", "classKernel_1_1LessRotateCCW__2.html#a5fba272f64c41eac4fcea0887daa009d", null ]
    ] ],
    [ "Kernel::LessSignedDistanceToLine_2", "classKernel_1_1LessSignedDistanceToLine__2.html", [
      [ "operator()", "classKernel_1_1LessSignedDistanceToLine__2.html#abb3c4eb854074a65c0ce64e6ddcc6c06", null ],
      [ "operator()", "classKernel_1_1LessSignedDistanceToLine__2.html#a66e60713775893000ead1a21b21b148a", null ]
    ] ],
    [ "Kernel::LessSignedDistanceToPlane_3", "classKernel_1_1LessSignedDistanceToPlane__3.html", [
      [ "operator()", "classKernel_1_1LessSignedDistanceToPlane__3.html#ac054fa2e3c17404e1e5fd6ff119c5a52", null ],
      [ "operator()", "classKernel_1_1LessSignedDistanceToPlane__3.html#ab68efd87026402d57bb3fef1609bd191", null ]
    ] ],
    [ "Kernel::LessXYZ_3", "classKernel_1_1LessXYZ__3.html", [
      [ "operator()", "classKernel_1_1LessXYZ__3.html#a5e417eb5fe1c52c00ce30652dea7d9a6", null ]
    ] ],
    [ "Kernel::LessXY_2", "classKernel_1_1LessXY__2.html", [
      [ "operator()", "classKernel_1_1LessXY__2.html#aaacc357900a68e05d441bb09811948a7", null ]
    ] ],
    [ "Kernel::LessXY_3", "classKernel_1_1LessXY__3.html", [
      [ "operator()", "classKernel_1_1LessXY__3.html#a2f4eab89b3980d521c3ff18b66cffa18", null ]
    ] ],
    [ "Kernel::LessX_2", "classKernel_1_1LessX__2.html", [
      [ "operator()", "classKernel_1_1LessX__2.html#a28193793893edd66271d52be339a3dce", null ]
    ] ],
    [ "Kernel::LessX_3", "classKernel_1_1LessX__3.html", [
      [ "operator()", "classKernel_1_1LessX__3.html#a03c19463abe4a910a79093cdc8cea942", null ]
    ] ],
    [ "Kernel::LessYX_2", "classKernel_1_1LessYX__2.html", [
      [ "operator()", "classKernel_1_1LessYX__2.html#a42f35afa7b54ca3a07ede2cec16039fe", null ]
    ] ],
    [ "Kernel::LessY_2", "classKernel_1_1LessY__2.html", [
      [ "operator()", "classKernel_1_1LessY__2.html#ae5175969b54ab9346929085768d9954d", null ]
    ] ],
    [ "Kernel::LessY_3", "classKernel_1_1LessY__3.html", [
      [ "operator()", "classKernel_1_1LessY__3.html#aefb5e72388ae764915fc4754347709d4", null ]
    ] ],
    [ "Kernel::LessZ_3", "classKernel_1_1LessZ__3.html", [
      [ "operator()", "classKernel_1_1LessZ__3.html#a1dc795f9ceb0777afb423643d813df32", null ]
    ] ],
    [ "Kernel::NonZeroCoordinateIndex_3", "classKernel_1_1NonZeroCoordinateIndex__3.html", [
      [ "operator()", "classKernel_1_1NonZeroCoordinateIndex__3.html#ad6488305f064400607492e5662972bed", null ]
    ] ],
    [ "Kernel::Orientation_2", "classKernel_1_1Orientation__2.html", [
      [ "operator()", "classKernel_1_1Orientation__2.html#a799f18593a893371fdd03b5cb4825dc2", null ],
      [ "operator()", "classKernel_1_1Orientation__2.html#a4d04415f403bd39bd881d4febebd05ad", null ]
    ] ],
    [ "Kernel::Orientation_3", "classKernel_1_1Orientation__3.html", [
      [ "operator()", "classKernel_1_1Orientation__3.html#a924bcdbae6397e395a6d11060ac155a8", null ],
      [ "operator()", "classKernel_1_1Orientation__3.html#a37ad1a4efab762784364daeef25c41ce", null ],
      [ "operator()", "classKernel_1_1Orientation__3.html#a598f5c7e0213d6724d127875edb0292b", null ]
    ] ],
    [ "Kernel::OrientedSide_2", "classKernel_1_1OrientedSide__2.html", [
      [ "operator()", "classKernel_1_1OrientedSide__2.html#a51dbb70767953e4a26d960ab8c845740", null ],
      [ "operator()", "classKernel_1_1OrientedSide__2.html#a8c1a8ea04ce08200fe4a68423473ea27", null ],
      [ "operator()", "classKernel_1_1OrientedSide__2.html#a192e534c25525dd3cc1993cfb01fbba2", null ],
      [ "operator()", "classKernel_1_1OrientedSide__2.html#a86dff8d8da51d45dcabb54facd1c0b6d", null ]
    ] ],
    [ "Kernel::OrientedSide_3", "classKernel_1_1OrientedSide__3.html", [
      [ "operator()", "classKernel_1_1OrientedSide__3.html#a9954d3294add7f353a59dab9c2d70947", null ],
      [ "operator()", "classKernel_1_1OrientedSide__3.html#a96d382d5b84e04af62252e3c47486ac5", null ],
      [ "operator()", "classKernel_1_1OrientedSide__3.html#a2bf6f7948068af789e018958ff078e42", null ],
      [ "operator()", "classKernel_1_1OrientedSide__3.html#ab476b741e51043672d6ff9988125aedc", null ]
    ] ],
    [ "Kernel::PowerSideOfBoundedPowerCircle_2", "classKernel_1_1PowerSideOfBoundedPowerCircle__2.html", [
      [ "operator()", "classKernel_1_1PowerSideOfBoundedPowerCircle__2.html#a08e7515d19ad0fa270b496fc3fa36228", null ],
      [ "operator()", "classKernel_1_1PowerSideOfBoundedPowerCircle__2.html#ad85d2482c619e1703d66c1da8f1acc85", null ],
      [ "operator()", "classKernel_1_1PowerSideOfBoundedPowerCircle__2.html#a5a13bce9d4fb65de5ab8298c6654d5da", null ]
    ] ],
    [ "Kernel::PowerSideOfBoundedPowerSphere_3", "classKernel_1_1PowerSideOfBoundedPowerSphere__3.html", [
      [ "operator()", "classKernel_1_1PowerSideOfBoundedPowerSphere__3.html#aa03802b2a6adf4376d418c01f7fc0b93", null ],
      [ "operator()", "classKernel_1_1PowerSideOfBoundedPowerSphere__3.html#a655887adf60c4dee76be966ae4c4c3e3", null ],
      [ "operator()", "classKernel_1_1PowerSideOfBoundedPowerSphere__3.html#a2dd289a4b2ce8b54999ece441e6433bd", null ],
      [ "operator()", "classKernel_1_1PowerSideOfBoundedPowerSphere__3.html#a26df9fce13e61c9d4d2f5fa05b5e0b81", null ]
    ] ],
    [ "Kernel::PowerSideOfOrientedPowerCircle_2", "classKernel_1_1PowerSideOfOrientedPowerCircle__2.html", [
      [ "operator()", "classKernel_1_1PowerSideOfOrientedPowerCircle__2.html#af38a8f08b8a0b2f1acf11cb72272b26b", null ]
    ] ],
    [ "Kernel::PowerSideOfOrientedPowerSphere_3", "classKernel_1_1PowerSideOfOrientedPowerSphere__3.html", [
      [ "operator()", "classKernel_1_1PowerSideOfOrientedPowerSphere__3.html#ab7b65e567d5d61c6241b89514cf32ac9", null ]
    ] ],
    [ "Kernel::SideOfBoundedCircle_2", "classKernel_1_1SideOfBoundedCircle__2.html", [
      [ "operator()", "classKernel_1_1SideOfBoundedCircle__2.html#aa3debccf06f258936066b864bddee89e", null ],
      [ "operator()", "classKernel_1_1SideOfBoundedCircle__2.html#a318d8121c94655b2be2838cce7478c7e", null ]
    ] ],
    [ "Kernel::SideOfBoundedSphere_3", "classKernel_1_1SideOfBoundedSphere__3.html", [
      [ "operator()", "classKernel_1_1SideOfBoundedSphere__3.html#ae070dd7b1b97236ada8665070cf142e0", null ],
      [ "operator()", "classKernel_1_1SideOfBoundedSphere__3.html#a325436bb066efb2cec46c923c91c4c5a", null ],
      [ "operator()", "classKernel_1_1SideOfBoundedSphere__3.html#a0c737b4b0c97263170ddf47d1a904906", null ]
    ] ],
    [ "Kernel::SideOfOrientedCircle_2", "classKernel_1_1SideOfOrientedCircle__2.html", [
      [ "operator()", "classKernel_1_1SideOfOrientedCircle__2.html#a2f2d14e80a7dac924d9bc350c5f9d994", null ]
    ] ],
    [ "Kernel::SideOfOrientedSphere_3", "classKernel_1_1SideOfOrientedSphere__3.html", [
      [ "operator()", "classKernel_1_1SideOfOrientedSphere__3.html#a829ec0d292d927a7bc70d1598900fbdd", null ]
    ] ]
];